#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class multi_layer_refinement:
    fluent_name = ...
    child_names = ...
    type = ...
    layer_count = ...
    boundary_list = ...
    command_names = ...

    def refine_mesh(self, ):
        """
        Refine the mesh for multiple boundary layers.
        """




import pytest
from util.solver_workflow import new_solver_session_no_transcript  # noqa: F401

from ansys.fluent.core.examples import download_file, path
from ansys.fluent.core.filereader.casereader import CaseReader


def test_get_and_set_rp_vars(new_solver_session_no_transcript) -> None:
    case_path = download_file("Static_Mixer_main.cas.h5", "pyfluent/static_mixer")
    solver = new_solver_session_no_transcript
    solver.tui.file.read_case(case_path)
    rp_vars = solver.rp_vars

    # simple integer
    iter_count = 54321
    rp_vars("number-of-iterations", iter_count)
    assert iter_count == rp_vars("number-of-iterations")

    # complex list structure
    before_init_mod = rp_vars("strategy/solution-strategy/before-init-modification")
    assert before_init_mod[1][1][1] == ("value", False)
    before_init_mod[1][1][1] = ("value", True)
    rp_vars("strategy/solution-strategy/before-init-modification", before_init_mod)
    before_init_mod_2 = rp_vars("strategy/solution-strategy/before-init-modification")
    assert before_init_mod_2[1][1][1] == ("value", True)


@pytest.mark.fluent_version(">=23.1, !=24.1")
def test_get_all_rp_vars(new_solver_session_no_transcript) -> None:
    case_path = download_file("Static_Mixer_main.cas.h5", "pyfluent/static_mixer")
    solver = new_solver_session_no_transcript
    solver.tui.file.read_case(case_path)
    rp_vars = solver.rp_vars
    # all vars
    all_vars = rp_vars()
    assert len(all_vars) == pytest.approx(9000, 10)

    # refresh
    solver.file.write(file_type="case", file_name=case_path)
    solver.tui.file.read_case(case_path)

    # all vars again
    all_vars = rp_vars()
    assert len(all_vars) == pytest.approx(9000, 20)

    # CaseFile comparison, note that the PyFluent work dir is not necessarily the same as the Fluent work dir
    case = CaseReader(case_file_name=path(case_path))
    case_vars = case.rp_vars()
    assert len(case_vars) == pytest.approx(9000, 450)


@pytest.mark.fluent_version(">=23.2")
def test_rp_vars_allowed_values(new_solver_session_no_transcript) -> None:
    solver = new_solver_session_no_transcript
    rp_vars = solver.rp_vars

    assert rp_vars("number-of-iterations") == 0

    with pytest.raises(RuntimeError) as msg:
        rp_vars("number-of-iterat")

    assert "number-of-iterations" in rp_vars.allowed_values()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fluid_1 import fluid as fluid_cls
from .solid_1 import solid as solid_cls
from .copy_1 import copy as copy_cls
from .set_zone_type import set_zone_type as set_zone_type_cls
from .activate_cell_zone import activate_cell_zone as activate_cell_zone_cls
from .mrf_to_sliding_mesh import mrf_to_sliding_mesh as mrf_to_sliding_mesh_cls
from .convert_all_solid_mrf_to_solid_motion import convert_all_solid_mrf_to_solid_motion as convert_all_solid_mrf_to_solid_motion_cls
from .copy_mrf_to_mesh_motion import copy_mrf_to_mesh_motion as copy_mrf_to_mesh_motion_cls
from .copy_mesh_to_mrf_motion import copy_mesh_to_mrf_motion as copy_mesh_to_mrf_motion_cls
class cell_zone_conditions(Group, _ChildNamedObjectAccessorMixin):
    """
    'cell_zone_conditions' child.
    """

    fluent_name = "cell-zone-conditions"

    child_names = \
        ['fluid', 'solid']

    fluid: fluid_cls = fluid_cls
    """
    fluid child of cell_zone_conditions.
    """
    solid: solid_cls = solid_cls
    """
    solid child of cell_zone_conditions.
    """
    command_names = \
        ['copy', 'set_zone_type', 'activate_cell_zone', 'mrf_to_sliding_mesh',
         'convert_all_solid_mrf_to_solid_motion', 'copy_mrf_to_mesh_motion',
         'copy_mesh_to_mrf_motion']

    copy: copy_cls = copy_cls
    """
    copy command of cell_zone_conditions.
    """
    set_zone_type: set_zone_type_cls = set_zone_type_cls
    """
    set_zone_type command of cell_zone_conditions.
    """
    activate_cell_zone: activate_cell_zone_cls = activate_cell_zone_cls
    """
    activate_cell_zone command of cell_zone_conditions.
    """
    mrf_to_sliding_mesh: mrf_to_sliding_mesh_cls = mrf_to_sliding_mesh_cls
    """
    mrf_to_sliding_mesh command of cell_zone_conditions.
    """
    convert_all_solid_mrf_to_solid_motion: convert_all_solid_mrf_to_solid_motion_cls = convert_all_solid_mrf_to_solid_motion_cls
    """
    convert_all_solid_mrf_to_solid_motion command of cell_zone_conditions.
    """
    copy_mrf_to_mesh_motion: copy_mrf_to_mesh_motion_cls = copy_mrf_to_mesh_motion_cls
    """
    copy_mrf_to_mesh_motion command of cell_zone_conditions.
    """
    copy_mesh_to_mrf_motion: copy_mesh_to_mrf_motion_cls = copy_mesh_to_mrf_motion_cls
    """
    copy_mesh_to_mrf_motion command of cell_zone_conditions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .constant import constant as constant_cls
from .coefficients import coefficients as coefficients_cls
from .number_of_coefficients import number_of_coefficients as number_of_coefficients_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
class conductivity(Group):
    """
    'conductivity' child.
    """

    fluent_name = "conductivity"

    child_names = \
        ['option', 'constant', 'coefficients', 'number_of_coefficients',
         'piecewise_linear', 'piecewise_polynomial']

    option: option_cls = option_cls
    """
    option child of conductivity.
    """
    constant: constant_cls = constant_cls
    """
    constant child of conductivity.
    """
    coefficients: coefficients_cls = coefficients_cls
    """
    coefficients child of conductivity.
    """
    number_of_coefficients: number_of_coefficients_cls = number_of_coefficients_cls
    """
    number_of_coefficients child of conductivity.
    """
    piecewise_linear: piecewise_linear_cls = piecewise_linear_cls
    """
    piecewise_linear child of conductivity.
    """
    piecewise_polynomial: piecewise_polynomial_cls = piecewise_polynomial_cls
    """
    piecewise_polynomial child of conductivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class auto_options:
    fluent_name = ...
    child_names = ...
    proximity_tolerance = ...
    set_default_name_prefix = ...
    set_one_to_one_pairing_tolerance = ...
    set_minimum_area_percentage = ...
    pairing_between_different_cell_zones_only = ...
    pairing_between_interface_zones_only = ...
    keep_empty_interface = ...
    command_names = ...

    def naming_option(self, option: int, change_all_o2o_si_names: bool):
        """
        Specify whether or not to include an informative suffix to the mesh interface name.
        
        Parameters
        ----------
            option : int
                'option' child.
            change_all_o2o_si_names : bool
                'change_all_o2o_si_names' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .dynamic_mechanism_reduction_tolerance import dynamic_mechanism_reduction_tolerance as dynamic_mechanism_reduction_tolerance_cls
from .dynamic_mechanism_reduction_expert import dynamic_mechanism_reduction_expert as dynamic_mechanism_reduction_expert_cls
from .dynamic_mechanism_reduction_min_target import dynamic_mechanism_reduction_min_target as dynamic_mechanism_reduction_min_target_cls
from .dynamic_mechanism_reduction_target_threshold import dynamic_mechanism_reduction_target_threshold as dynamic_mechanism_reduction_target_threshold_cls
from .dynamic_mechanism_reduction_targets import dynamic_mechanism_reduction_targets as dynamic_mechanism_reduction_targets_cls
class dynamic_mechanism_reduction_options(Group):
    """
    'dynamic_mechanism_reduction_options' child.
    """

    fluent_name = "dynamic-mechanism-reduction-options"

    child_names = \
        ['dynamic_mechanism_reduction_tolerance',
         'dynamic_mechanism_reduction_expert',
         'dynamic_mechanism_reduction_min_target',
         'dynamic_mechanism_reduction_target_threshold',
         'dynamic_mechanism_reduction_targets']

    dynamic_mechanism_reduction_tolerance: dynamic_mechanism_reduction_tolerance_cls = dynamic_mechanism_reduction_tolerance_cls
    """
    dynamic_mechanism_reduction_tolerance child of dynamic_mechanism_reduction_options.
    """
    dynamic_mechanism_reduction_expert: dynamic_mechanism_reduction_expert_cls = dynamic_mechanism_reduction_expert_cls
    """
    dynamic_mechanism_reduction_expert child of dynamic_mechanism_reduction_options.
    """
    dynamic_mechanism_reduction_min_target: dynamic_mechanism_reduction_min_target_cls = dynamic_mechanism_reduction_min_target_cls
    """
    dynamic_mechanism_reduction_min_target child of dynamic_mechanism_reduction_options.
    """
    dynamic_mechanism_reduction_target_threshold: dynamic_mechanism_reduction_target_threshold_cls = dynamic_mechanism_reduction_target_threshold_cls
    """
    dynamic_mechanism_reduction_target_threshold child of dynamic_mechanism_reduction_options.
    """
    dynamic_mechanism_reduction_targets: dynamic_mechanism_reduction_targets_cls = dynamic_mechanism_reduction_targets_cls
    """
    dynamic_mechanism_reduction_targets child of dynamic_mechanism_reduction_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .turbulent_rate_constant import turbulent_rate_constant as turbulent_rate_constant_cls
from .chemical_rate_constant import chemical_rate_constant as chemical_rate_constant_cls
from .fuel_species import fuel_species as fuel_species_cls
from .equilibrium_rich_flammability import equilibrium_rich_flammability as equilibrium_rich_flammability_cls
from .equilibrium_rich_flammability_options import equilibrium_rich_flammability_options as equilibrium_rich_flammability_options_cls
class relax_to_equilibrium_options(Group):
    """
    'relax_to_equilibrium_options' child.
    """

    fluent_name = "relax-to-equilibrium-options"

    child_names = \
        ['turbulent_rate_constant', 'chemical_rate_constant', 'fuel_species',
         'equilibrium_rich_flammability',
         'equilibrium_rich_flammability_options']

    turbulent_rate_constant: turbulent_rate_constant_cls = turbulent_rate_constant_cls
    """
    turbulent_rate_constant child of relax_to_equilibrium_options.
    """
    chemical_rate_constant: chemical_rate_constant_cls = chemical_rate_constant_cls
    """
    chemical_rate_constant child of relax_to_equilibrium_options.
    """
    fuel_species: fuel_species_cls = fuel_species_cls
    """
    fuel_species child of relax_to_equilibrium_options.
    """
    equilibrium_rich_flammability: equilibrium_rich_flammability_cls = equilibrium_rich_flammability_cls
    """
    equilibrium_rich_flammability child of relax_to_equilibrium_options.
    """
    equilibrium_rich_flammability_options: equilibrium_rich_flammability_options_cls = equilibrium_rich_flammability_options_cls
    """
    equilibrium_rich_flammability_options child of relax_to_equilibrium_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name']

    name: name_cls = name_cls
    """
    name child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

"""A package providing Fluent's Settings Objects in Python."""
from ansys.fluent.core.solver.flobject import *

SHASH = "765e2322465ad0dce0f3a485fecd7758579360f595e5794ec0bbd90ed82ae94e"
from .root import root


import os
from typing import TypeVar

from ansys.fluent.core.services.scheme_eval import SchemeEval
from ansys.fluent.core.utils.fluent_version import FluentVersion

_TApiUpgradeAdvisor = TypeVar("_TApiUpgradeAdvisor", bound="ApiUpgradeAdvisor")


class ApiUpgradeAdvisor:
    def __init__(self, scheme_eval: SchemeEval, version: str, mode: str) -> None:
        self._scheme_eval = scheme_eval.scheme_eval
        self._version = version
        self._mode = mode

    def _can_advise(self) -> bool:
        return (
            not os.getenv("PYFLUENT_SKIP_API_UPGRADE_ADVICE")
            and FluentVersion(self._version) >= FluentVersion.v231
            and self._mode == "solver"
        )

    def __enter__(self) -> _TApiUpgradeAdvisor:
        if self._can_advise():
            self._scheme_eval("(define pyfluent-journal-str-port (open-output-string))")
            self._scheme_eval("(api-echo-python-port pyfluent-journal-str-port)")
        return self

    def __exit__(self, exc_type, exc_value, exc_tb) -> None:
        if self._can_advise():
            self._scheme_eval("(api-unecho-python-port pyfluent-journal-str-port)")
            journal_str = self._scheme_eval(
                "(close-output-port pyfluent-journal-str-port)"
            ).strip()
            if (
                journal_str.startswith("solver.")
                and not journal_str.startswith("solver.tui")
                and not journal_str.startswith("solver.execute_tui")
            ):
                print(
                    "The following solver settings object method could also be used to execute the above command:"
                )
                print(f"<solver_session>.{journal_str[len('solver.'):]}")



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .is_not_a_rans_les_interface import is_not_a_rans_les_interface as is_not_a_rans_les_interface_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['is_not_a_rans_les_interface']

    is_not_a_rans_les_interface: is_not_a_rans_les_interface_cls = is_not_a_rans_les_interface_cls
    """
    is_not_a_rans_les_interface child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .solution_stabilization import solution_stabilization as solution_stabilization_cls
from .verbosity_1 import verbosity as verbosity_cls
from .parameters import parameters as parameters_cls
from .spatial import spatial as spatial_cls
from .transient import transient as transient_cls
from .amg import amg as amg_cls
from .models_2 import models as models_cls
from .methods import methods as methods_cls
from .miscellaneous import miscellaneous as miscellaneous_cls
from .set_settings_to_default import set_settings_to_default as set_settings_to_default_cls
class contact_solution_controls(Group):
    """
    'contact_solution_controls' child.
    """

    fluent_name = "contact-solution-controls"

    child_names = \
        ['solution_stabilization', 'verbosity', 'parameters', 'spatial',
         'transient', 'amg', 'models', 'methods', 'miscellaneous']

    solution_stabilization: solution_stabilization_cls = solution_stabilization_cls
    """
    solution_stabilization child of contact_solution_controls.
    """
    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity child of contact_solution_controls.
    """
    parameters: parameters_cls = parameters_cls
    """
    parameters child of contact_solution_controls.
    """
    spatial: spatial_cls = spatial_cls
    """
    spatial child of contact_solution_controls.
    """
    transient: transient_cls = transient_cls
    """
    transient child of contact_solution_controls.
    """
    amg: amg_cls = amg_cls
    """
    amg child of contact_solution_controls.
    """
    models: models_cls = models_cls
    """
    models child of contact_solution_controls.
    """
    methods: methods_cls = methods_cls
    """
    methods child of contact_solution_controls.
    """
    miscellaneous: miscellaneous_cls = miscellaneous_cls
    """
    miscellaneous child of contact_solution_controls.
    """
    command_names = \
        ['set_settings_to_default']

    set_settings_to_default: set_settings_to_default_cls = set_settings_to_default_cls
    """
    set_settings_to_default command of contact_solution_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .initial_soc import initial_soc as initial_soc_cls
from .ref_capacity import ref_capacity as ref_capacity_cls
from .anode_thickness import anode_thickness as anode_thickness_cls
from .anode_n_grid import anode_n_grid as anode_n_grid_cls
from .anode_size_ratio import anode_size_ratio as anode_size_ratio_cls
from .anode_p_diameter import anode_p_diameter as anode_p_diameter_cls
from .anode_n_sphere import anode_n_sphere as anode_n_sphere_cls
from .anode_size_ratio_r import anode_size_ratio_r as anode_size_ratio_r_cls
from .anode_cs_max import anode_cs_max as anode_cs_max_cls
from .anode_stio_0 import anode_stio_0 as anode_stio_0_cls
from .anode_stio_100 import anode_stio_100 as anode_stio_100_cls
from .anode_ce_0 import anode_ce_0 as anode_ce_0_cls
from .anode_vof import anode_vof as anode_vof_cls
from .anode_filler_f import anode_filler_f as anode_filler_f_cls
from .anode_ds import anode_ds as anode_ds_cls
from .anode_ed import anode_ed as anode_ed_cls
from .anode_brugg import anode_brugg as anode_brugg_cls
from .anode_sigma import anode_sigma as anode_sigma_cls
from .anode_i0_1 import anode_i0 as anode_i0_cls
from .anode_er import anode_er as anode_er_cls
from .anode_alpha_a_1 import anode_alpha_a as anode_alpha_a_cls
from .anode_alpha_c_1 import anode_alpha_c as anode_alpha_c_cls
from .anode_ocv import anode_ocv as anode_ocv_cls
from .cathode_thickness import cathode_thickness as cathode_thickness_cls
from .cathode_n_grid import cathode_n_grid as cathode_n_grid_cls
from .cathode_size_ratio import cathode_size_ratio as cathode_size_ratio_cls
from .cathode_p_diameter import cathode_p_diameter as cathode_p_diameter_cls
from .cathode_n_sphere import cathode_n_sphere as cathode_n_sphere_cls
from .cathode_size_ratio_r import cathode_size_ratio_r as cathode_size_ratio_r_cls
from .cathode_cs_max import cathode_cs_max as cathode_cs_max_cls
from .cathode_stio_0 import cathode_stio_0 as cathode_stio_0_cls
from .cathode_stio_100 import cathode_stio_100 as cathode_stio_100_cls
from .cathode_ce_0 import cathode_ce_0 as cathode_ce_0_cls
from .cathode_vof import cathode_vof as cathode_vof_cls
from .cathode_filler_f import cathode_filler_f as cathode_filler_f_cls
from .cathode_ds import cathode_ds as cathode_ds_cls
from .cathode_ed import cathode_ed as cathode_ed_cls
from .cathode_brugg import cathode_brugg as cathode_brugg_cls
from .cathode_sigma import cathode_sigma as cathode_sigma_cls
from .cathode_i0_1 import cathode_i0 as cathode_i0_cls
from .cathode_er import cathode_er as cathode_er_cls
from .cathode_alpha_a_1 import cathode_alpha_a as cathode_alpha_a_cls
from .cathode_alpha_c_1 import cathode_alpha_c as cathode_alpha_c_cls
from .cathode_ocv import cathode_ocv as cathode_ocv_cls
from .electrolyte_thickness import electrolyte_thickness as electrolyte_thickness_cls
from .electrolyte_n_grid import electrolyte_n_grid as electrolyte_n_grid_cls
from .electrolyte_ce_0 import electrolyte_ce_0 as electrolyte_ce_0_cls
from .electrolyte_vof import electrolyte_vof as electrolyte_vof_cls
from .electrolyte_brugg import electrolyte_brugg as electrolyte_brugg_cls
from .electrolyte_de import electrolyte_de as electrolyte_de_cls
from .electrolyte_t_plus import electrolyte_t_plus as electrolyte_t_plus_cls
from .electrolyte_sigma import electrolyte_sigma as electrolyte_sigma_cls
from .electrolyte_activity import electrolyte_activity as electrolyte_activity_cls
from .analytical_cs import analytical_cs as analytical_cs_cls
from .analytical_cs_order import analytical_cs_order as analytical_cs_order_cls
from .aging_model_enabled import aging_model_enabled as aging_model_enabled_cls
from .swelling_model_enabled import swelling_model_enabled as swelling_model_enabled_cls
from .swelling_model_parameter import swelling_model_parameter as swelling_model_parameter_cls
class p2d_model_settings(Group):
    """
    'p2d_model_settings' child.
    """

    fluent_name = "p2d-model-settings"

    child_names = \
        ['initial_soc', 'ref_capacity', 'anode_thickness', 'anode_n_grid',
         'anode_size_ratio', 'anode_p_diameter', 'anode_n_sphere',
         'anode_size_ratio_r', 'anode_cs_max', 'anode_stio_0',
         'anode_stio_100', 'anode_ce_0', 'anode_vof', 'anode_filler_f',
         'anode_ds', 'anode_ed', 'anode_brugg', 'anode_sigma', 'anode_i0',
         'anode_er', 'anode_alpha_a', 'anode_alpha_c', 'anode_ocv',
         'cathode_thickness', 'cathode_n_grid', 'cathode_size_ratio',
         'cathode_p_diameter', 'cathode_n_sphere', 'cathode_size_ratio_r',
         'cathode_cs_max', 'cathode_stio_0', 'cathode_stio_100',
         'cathode_ce_0', 'cathode_vof', 'cathode_filler_f', 'cathode_ds',
         'cathode_ed', 'cathode_brugg', 'cathode_sigma', 'cathode_i0',
         'cathode_er', 'cathode_alpha_a', 'cathode_alpha_c', 'cathode_ocv',
         'electrolyte_thickness', 'electrolyte_n_grid', 'electrolyte_ce_0',
         'electrolyte_vof', 'electrolyte_brugg', 'electrolyte_de',
         'electrolyte_t_plus', 'electrolyte_sigma', 'electrolyte_activity',
         'analytical_cs', 'analytical_cs_order', 'aging_model_enabled',
         'swelling_model_enabled', 'swelling_model_parameter']

    initial_soc: initial_soc_cls = initial_soc_cls
    """
    initial_soc child of p2d_model_settings.
    """
    ref_capacity: ref_capacity_cls = ref_capacity_cls
    """
    ref_capacity child of p2d_model_settings.
    """
    anode_thickness: anode_thickness_cls = anode_thickness_cls
    """
    anode_thickness child of p2d_model_settings.
    """
    anode_n_grid: anode_n_grid_cls = anode_n_grid_cls
    """
    anode_n_grid child of p2d_model_settings.
    """
    anode_size_ratio: anode_size_ratio_cls = anode_size_ratio_cls
    """
    anode_size_ratio child of p2d_model_settings.
    """
    anode_p_diameter: anode_p_diameter_cls = anode_p_diameter_cls
    """
    anode_p_diameter child of p2d_model_settings.
    """
    anode_n_sphere: anode_n_sphere_cls = anode_n_sphere_cls
    """
    anode_n_sphere child of p2d_model_settings.
    """
    anode_size_ratio_r: anode_size_ratio_r_cls = anode_size_ratio_r_cls
    """
    anode_size_ratio_r child of p2d_model_settings.
    """
    anode_cs_max: anode_cs_max_cls = anode_cs_max_cls
    """
    anode_cs_max child of p2d_model_settings.
    """
    anode_stio_0: anode_stio_0_cls = anode_stio_0_cls
    """
    anode_stio_0 child of p2d_model_settings.
    """
    anode_stio_100: anode_stio_100_cls = anode_stio_100_cls
    """
    anode_stio_100 child of p2d_model_settings.
    """
    anode_ce_0: anode_ce_0_cls = anode_ce_0_cls
    """
    anode_ce_0 child of p2d_model_settings.
    """
    anode_vof: anode_vof_cls = anode_vof_cls
    """
    anode_vof child of p2d_model_settings.
    """
    anode_filler_f: anode_filler_f_cls = anode_filler_f_cls
    """
    anode_filler_f child of p2d_model_settings.
    """
    anode_ds: anode_ds_cls = anode_ds_cls
    """
    anode_ds child of p2d_model_settings.
    """
    anode_ed: anode_ed_cls = anode_ed_cls
    """
    anode_ed child of p2d_model_settings.
    """
    anode_brugg: anode_brugg_cls = anode_brugg_cls
    """
    anode_brugg child of p2d_model_settings.
    """
    anode_sigma: anode_sigma_cls = anode_sigma_cls
    """
    anode_sigma child of p2d_model_settings.
    """
    anode_i0: anode_i0_cls = anode_i0_cls
    """
    anode_i0 child of p2d_model_settings.
    """
    anode_er: anode_er_cls = anode_er_cls
    """
    anode_er child of p2d_model_settings.
    """
    anode_alpha_a: anode_alpha_a_cls = anode_alpha_a_cls
    """
    anode_alpha_a child of p2d_model_settings.
    """
    anode_alpha_c: anode_alpha_c_cls = anode_alpha_c_cls
    """
    anode_alpha_c child of p2d_model_settings.
    """
    anode_ocv: anode_ocv_cls = anode_ocv_cls
    """
    anode_ocv child of p2d_model_settings.
    """
    cathode_thickness: cathode_thickness_cls = cathode_thickness_cls
    """
    cathode_thickness child of p2d_model_settings.
    """
    cathode_n_grid: cathode_n_grid_cls = cathode_n_grid_cls
    """
    cathode_n_grid child of p2d_model_settings.
    """
    cathode_size_ratio: cathode_size_ratio_cls = cathode_size_ratio_cls
    """
    cathode_size_ratio child of p2d_model_settings.
    """
    cathode_p_diameter: cathode_p_diameter_cls = cathode_p_diameter_cls
    """
    cathode_p_diameter child of p2d_model_settings.
    """
    cathode_n_sphere: cathode_n_sphere_cls = cathode_n_sphere_cls
    """
    cathode_n_sphere child of p2d_model_settings.
    """
    cathode_size_ratio_r: cathode_size_ratio_r_cls = cathode_size_ratio_r_cls
    """
    cathode_size_ratio_r child of p2d_model_settings.
    """
    cathode_cs_max: cathode_cs_max_cls = cathode_cs_max_cls
    """
    cathode_cs_max child of p2d_model_settings.
    """
    cathode_stio_0: cathode_stio_0_cls = cathode_stio_0_cls
    """
    cathode_stio_0 child of p2d_model_settings.
    """
    cathode_stio_100: cathode_stio_100_cls = cathode_stio_100_cls
    """
    cathode_stio_100 child of p2d_model_settings.
    """
    cathode_ce_0: cathode_ce_0_cls = cathode_ce_0_cls
    """
    cathode_ce_0 child of p2d_model_settings.
    """
    cathode_vof: cathode_vof_cls = cathode_vof_cls
    """
    cathode_vof child of p2d_model_settings.
    """
    cathode_filler_f: cathode_filler_f_cls = cathode_filler_f_cls
    """
    cathode_filler_f child of p2d_model_settings.
    """
    cathode_ds: cathode_ds_cls = cathode_ds_cls
    """
    cathode_ds child of p2d_model_settings.
    """
    cathode_ed: cathode_ed_cls = cathode_ed_cls
    """
    cathode_ed child of p2d_model_settings.
    """
    cathode_brugg: cathode_brugg_cls = cathode_brugg_cls
    """
    cathode_brugg child of p2d_model_settings.
    """
    cathode_sigma: cathode_sigma_cls = cathode_sigma_cls
    """
    cathode_sigma child of p2d_model_settings.
    """
    cathode_i0: cathode_i0_cls = cathode_i0_cls
    """
    cathode_i0 child of p2d_model_settings.
    """
    cathode_er: cathode_er_cls = cathode_er_cls
    """
    cathode_er child of p2d_model_settings.
    """
    cathode_alpha_a: cathode_alpha_a_cls = cathode_alpha_a_cls
    """
    cathode_alpha_a child of p2d_model_settings.
    """
    cathode_alpha_c: cathode_alpha_c_cls = cathode_alpha_c_cls
    """
    cathode_alpha_c child of p2d_model_settings.
    """
    cathode_ocv: cathode_ocv_cls = cathode_ocv_cls
    """
    cathode_ocv child of p2d_model_settings.
    """
    electrolyte_thickness: electrolyte_thickness_cls = electrolyte_thickness_cls
    """
    electrolyte_thickness child of p2d_model_settings.
    """
    electrolyte_n_grid: electrolyte_n_grid_cls = electrolyte_n_grid_cls
    """
    electrolyte_n_grid child of p2d_model_settings.
    """
    electrolyte_ce_0: electrolyte_ce_0_cls = electrolyte_ce_0_cls
    """
    electrolyte_ce_0 child of p2d_model_settings.
    """
    electrolyte_vof: electrolyte_vof_cls = electrolyte_vof_cls
    """
    electrolyte_vof child of p2d_model_settings.
    """
    electrolyte_brugg: electrolyte_brugg_cls = electrolyte_brugg_cls
    """
    electrolyte_brugg child of p2d_model_settings.
    """
    electrolyte_de: electrolyte_de_cls = electrolyte_de_cls
    """
    electrolyte_de child of p2d_model_settings.
    """
    electrolyte_t_plus: electrolyte_t_plus_cls = electrolyte_t_plus_cls
    """
    electrolyte_t_plus child of p2d_model_settings.
    """
    electrolyte_sigma: electrolyte_sigma_cls = electrolyte_sigma_cls
    """
    electrolyte_sigma child of p2d_model_settings.
    """
    electrolyte_activity: electrolyte_activity_cls = electrolyte_activity_cls
    """
    electrolyte_activity child of p2d_model_settings.
    """
    analytical_cs: analytical_cs_cls = analytical_cs_cls
    """
    analytical_cs child of p2d_model_settings.
    """
    analytical_cs_order: analytical_cs_order_cls = analytical_cs_order_cls
    """
    analytical_cs_order child of p2d_model_settings.
    """
    aging_model_enabled: aging_model_enabled_cls = aging_model_enabled_cls
    """
    aging_model_enabled child of p2d_model_settings.
    """
    swelling_model_enabled: swelling_model_enabled_cls = swelling_model_enabled_cls
    """
    swelling_model_enabled child of p2d_model_settings.
    """
    swelling_model_parameter: swelling_model_parameter_cls = swelling_model_parameter_cls
    """
    swelling_model_parameter child of p2d_model_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .simulation_reports import simulation_reports as simulation_reports_cls
from .discrete_phase_1 import discrete_phase as discrete_phase_cls
from .fluxes import fluxes as fluxes_cls
from .flow import flow as flow_cls
from .modified_setting_options import modified_setting_options as modified_setting_options_cls
from .population_balance import population_balance as population_balance_cls
from .heat_exchange import heat_exchange as heat_exchange_cls
from .system import system as system_cls
from .print_write_histogram import print_write_histogram as print_write_histogram_cls
from .aero_optical_distortions import aero_optical_distortions as aero_optical_distortions_cls
from .forces import forces as forces_cls
from .mphase_summary import mphase_summary as mphase_summary_cls
from .particle_summary import particle_summary as particle_summary_cls
from .path_line_summary import path_line_summary as path_line_summary_cls
from .projected_surface_area import projected_surface_area as projected_surface_area_cls
from .summary_1 import summary as summary_cls
from .surface_integrals import surface_integrals as surface_integrals_cls
from .volume_integrals import volume_integrals as volume_integrals_cls
class report(Group):
    """
    'report' child.
    """

    fluent_name = "report"

    child_names = \
        ['simulation_reports', 'discrete_phase', 'fluxes', 'flow',
         'modified_setting_options', 'population_balance', 'heat_exchange',
         'system', 'print_write_histogram']

    simulation_reports: simulation_reports_cls = simulation_reports_cls
    """
    simulation_reports child of report.
    """
    discrete_phase: discrete_phase_cls = discrete_phase_cls
    """
    discrete_phase child of report.
    """
    fluxes: fluxes_cls = fluxes_cls
    """
    fluxes child of report.
    """
    flow: flow_cls = flow_cls
    """
    flow child of report.
    """
    modified_setting_options: modified_setting_options_cls = modified_setting_options_cls
    """
    modified_setting_options child of report.
    """
    population_balance: population_balance_cls = population_balance_cls
    """
    population_balance child of report.
    """
    heat_exchange: heat_exchange_cls = heat_exchange_cls
    """
    heat_exchange child of report.
    """
    system: system_cls = system_cls
    """
    system child of report.
    """
    print_write_histogram: print_write_histogram_cls = print_write_histogram_cls
    """
    print_write_histogram child of report.
    """
    command_names = \
        ['aero_optical_distortions', 'forces', 'mphase_summary',
         'particle_summary', 'path_line_summary', 'projected_surface_area',
         'summary', 'surface_integrals', 'volume_integrals']

    aero_optical_distortions: aero_optical_distortions_cls = aero_optical_distortions_cls
    """
    aero_optical_distortions command of report.
    """
    forces: forces_cls = forces_cls
    """
    forces command of report.
    """
    mphase_summary: mphase_summary_cls = mphase_summary_cls
    """
    mphase_summary command of report.
    """
    particle_summary: particle_summary_cls = particle_summary_cls
    """
    particle_summary command of report.
    """
    path_line_summary: path_line_summary_cls = path_line_summary_cls
    """
    path_line_summary command of report.
    """
    projected_surface_area: projected_surface_area_cls = projected_surface_area_cls
    """
    projected_surface_area command of report.
    """
    summary: summary_cls = summary_cls
    """
    summary command of report.
    """
    surface_integrals: surface_integrals_cls = surface_integrals_cls
    """
    surface_integrals command of report.
    """
    volume_integrals: volume_integrals_cls = volume_integrals_cls
    """
    volume_integrals command of report.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .boundary_zone import boundary_zone as boundary_zone_cls
from .flat_init import flat_init as flat_init_cls
from .wavy_surface_init import wavy_surface_init as wavy_surface_init_cls
class open_channel_auto_init(Group):
    """
    Open channel automatic initialization.
    """

    fluent_name = "open-channel-auto-init"

    child_names = \
        ['boundary_zone', 'flat_init', 'wavy_surface_init']

    boundary_zone: boundary_zone_cls = boundary_zone_cls
    """
    boundary_zone child of open_channel_auto_init.
    """
    flat_init: flat_init_cls = flat_init_cls
    """
    flat_init child of open_channel_auto_init.
    """
    wavy_surface_init: wavy_surface_init_cls = wavy_surface_init_cls
    """
    wavy_surface_init child of open_channel_auto_init.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class mesh:
    fluent_name = ...
    child_names = ...
    adapt = ...
    check_before_solve = ...
    check_verbosity = ...
    enhanced_orthogonal_quality = ...
    matching_tolerance = ...
    show_periodic_shadow_zones = ...
    reorder = ...
    repair_improve = ...
    surface_mesh = ...
    polyhedra = ...
    command_names = ...

    def adjacency(self, ):
        """
        View and rename face zones adjacent to selected cell zones.
        """

    def check(self, ):
        """
        Perform various mesh consistency checks.
        """

    def memory_usage(self, ):
        """
        Report solver memory use.
        """

    def mesh_info(self, print_level: int):
        """
        'mesh_info' command.
        
        Parameters
        ----------
            print_level : int
                Print zone information size.
        
        """

    def quality(self, ):
        """
        Perform analysis of mesh quality.
        """

    def rotate(self, angle: Union[float, str], origin: Tuple[Union[float, str], Union[float, str], Union[float, str], axis_components: Tuple[Union[float, str], Union[float, str], Union[float, str]):
        """
        Rotate the mesh.
        
        Parameters
        ----------
            angle : real
                'angle' child.
            origin : typing.Tuple[real, real, real]
                'origin' child.
            axis_components : typing.Tuple[real, real, real]
                'axis_components' child.
        
        """

    def scale(self, x_scale: Union[float, str], y_scale: Union[float, str], z_scale: Union[float, str]):
        """
        'scale' command.
        
        Parameters
        ----------
            x_scale : real
                'x_scale' child.
            y_scale : real
                'y_scale' child.
            z_scale : real
                'z_scale' child.
        
        """

    def size_info(self, ):
        """
        Print mesh size.
        """

    def redistribute_boundary_layer(self, thread_id: int, growth_rate: Union[float, str]):
        """
        Enforce growth rate in boundary layer.
        
        Parameters
        ----------
            thread_id : int
                'thread_id' child.
            growth_rate : real
                'growth_rate' child.
        
        """

    def swap_mesh_faces(self, ):
        """
        Swap mesh faces.
        """

    def smooth_mesh(self, type_of_smoothing: str, number_of_iterations: int, relaxtion_factor: Union[float, str], percentage_of_cells: Union[float, str], skewness_threshold: Union[float, str]):
        """
        Smooth the mesh using quality-based, Laplace or skewness methods.
        
        Parameters
        ----------
            type_of_smoothing : str
                'type_of_smoothing' child.
            number_of_iterations : int
                'number_of_iterations' child.
            relaxtion_factor : real
                'relaxtion_factor' child.
            percentage_of_cells : real
                'percentage_of_cells' child.
            skewness_threshold : real
                'skewness_threshold' child.
        
        """

    def replace(self, name: str, zones: bool):
        """
        Replace mesh and interpolate data.
        
        Parameters
        ----------
            name : str
                'name' child.
            zones : bool
                'zones' child.
        
        """

    def translate(self, offset: Tuple[Union[float, str], Union[float, str], Union[float, str]):
        """
        Translate the mesh.
        
        Parameters
        ----------
            offset : typing.Tuple[real, real, real]
                'offset' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_7 import option as option_cls
from .neutral_involved_interaction import neutral_involved_interaction as neutral_involved_interaction_cls
from .charged_particle_interaction import charged_particle_interaction as charged_particle_interaction_cls
class child_object_type_child(Group):
    """
    'child_object_type' of child_object_type.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['option', 'neutral_involved_interaction',
         'charged_particle_interaction']

    option: option_cls = option_cls
    """
    option child of child_object_type_child.
    """
    neutral_involved_interaction: neutral_involved_interaction_cls = neutral_involved_interaction_cls
    """
    neutral_involved_interaction child of child_object_type_child.
    """
    charged_particle_interaction: charged_particle_interaction_cls = charged_particle_interaction_cls
    """
    charged_particle_interaction child of child_object_type_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .color_mode import color_mode as color_mode_cls
from .driver_options import driver_options as driver_options_cls
from .invert_background import invert_background as invert_background_cls
from .landscape import landscape as landscape_cls
from .x_resolution import x_resolution as x_resolution_cls
from .y_resolution import y_resolution as y_resolution_cls
from .dpi import dpi as dpi_cls
from .use_window_resolution import use_window_resolution as use_window_resolution_cls
from .standard_resolution import standard_resolution as standard_resolution_cls
from .jpeg_hardcopy_quality import jpeg_hardcopy_quality as jpeg_hardcopy_quality_cls
from .preview import preview as preview_cls
from .save_picture import save_picture as save_picture_cls
from .list_color_mode import list_color_mode as list_color_mode_cls
class picture(Group):
    """
    Enter the hardcopy/save-picture options menu.
    """

    fluent_name = "picture"

    child_names = \
        ['color_mode', 'driver_options', 'invert_background', 'landscape',
         'x_resolution', 'y_resolution', 'dpi', 'use_window_resolution',
         'standard_resolution', 'jpeg_hardcopy_quality']

    color_mode: color_mode_cls = color_mode_cls
    """
    color_mode child of picture.
    """
    driver_options: driver_options_cls = driver_options_cls
    """
    driver_options child of picture.
    """
    invert_background: invert_background_cls = invert_background_cls
    """
    invert_background child of picture.
    """
    landscape: landscape_cls = landscape_cls
    """
    landscape child of picture.
    """
    x_resolution: x_resolution_cls = x_resolution_cls
    """
    x_resolution child of picture.
    """
    y_resolution: y_resolution_cls = y_resolution_cls
    """
    y_resolution child of picture.
    """
    dpi: dpi_cls = dpi_cls
    """
    dpi child of picture.
    """
    use_window_resolution: use_window_resolution_cls = use_window_resolution_cls
    """
    use_window_resolution child of picture.
    """
    standard_resolution: standard_resolution_cls = standard_resolution_cls
    """
    standard_resolution child of picture.
    """
    jpeg_hardcopy_quality: jpeg_hardcopy_quality_cls = jpeg_hardcopy_quality_cls
    """
    jpeg_hardcopy_quality child of picture.
    """
    command_names = \
        ['preview', 'save_picture', 'list_color_mode']

    preview: preview_cls = preview_cls
    """
    preview command of picture.
    """
    save_picture: save_picture_cls = save_picture_cls
    """
    save_picture command of picture.
    """
    list_color_mode: list_color_mode_cls = list_color_mode_cls
    """
    list_color_mode command of picture.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_3 import enable as enable_cls
from .method import method as method_cls
from .value import value as value_cls
from .print_1 import print as print_cls
class operating_density(Group):
    """
    Enable/disable use of a specified operating density.
    """

    fluent_name = "operating-density"

    child_names = \
        ['enable', 'method', 'value']

    enable: enable_cls = enable_cls
    """
    enable child of operating_density.
    """
    method: method_cls = method_cls
    """
    method child of operating_density.
    """
    value: value_cls = value_cls
    """
    value child of operating_density.
    """
    command_names = \
        ['print']

    print: print_cls = print_cls
    """
    print command of operating_density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .object_at import object_at as object_at_cls
class list_properties(Command):
    """
    List properties of selected object.
    
    Parameters
    ----------
        object_at : int
            Select object index to delete.
    
    """

    fluent_name = "list-properties"

    argument_names = \
        ['object_at']

    object_at: object_at_cls = object_at_cls
    """
    object_at argument of list_properties.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .echem_stop_type import echem_stop_type as echem_stop_type_cls
from .min_voltage import min_voltage as min_voltage_cls
from .max_voltage import max_voltage as max_voltage_cls
from .min_soc import min_soc as min_soc_cls
from .max_soc import max_soc as max_soc_cls
class echem_stop_criterion(Group):
    """
    'echem_stop_criterion' child.
    """

    fluent_name = "echem-stop-criterion"

    child_names = \
        ['echem_stop_type', 'min_voltage', 'max_voltage', 'min_soc',
         'max_soc']

    echem_stop_type: echem_stop_type_cls = echem_stop_type_cls
    """
    echem_stop_type child of echem_stop_criterion.
    """
    min_voltage: min_voltage_cls = min_voltage_cls
    """
    min_voltage child of echem_stop_criterion.
    """
    max_voltage: max_voltage_cls = max_voltage_cls
    """
    max_voltage child of echem_stop_criterion.
    """
    min_soc: min_soc_cls = min_soc_cls
    """
    min_soc child of echem_stop_criterion.
    """
    max_soc: max_soc_cls = max_soc_cls
    """
    max_soc child of echem_stop_criterion.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .model import model as model_cls
from .options_2 import options as options_cls
from .spalart_allmaras_production import spalart_allmaras_production as spalart_allmaras_production_cls
from .k_epsilon_model import k_epsilon_model as k_epsilon_model_cls
from .k_omega_model import k_omega_model as k_omega_model_cls
from .k_omega_options import k_omega_options as k_omega_options_cls
from .rng_options import rng_options as rng_options_cls
from .near_wall_treatment import near_wall_treatment as near_wall_treatment_cls
from .reynolds_stress_model import reynolds_stress_model as reynolds_stress_model_cls
from .subgrid_scale_model import subgrid_scale_model as subgrid_scale_model_cls
from .les_model_options import les_model_options as les_model_options_cls
from .reynolds_stress_options import reynolds_stress_options as reynolds_stress_options_cls
from .rans_model import rans_model as rans_model_cls
from .des_options import des_options as des_options_cls
from .transition_module import transition_module as transition_module_cls
from .user_defined_transition import user_defined_transition as user_defined_transition_cls
from .multiphase_turbulence import multiphase_turbulence as multiphase_turbulence_cls
from .turbulence_expert import turbulence_expert as turbulence_expert_cls
from .geko_options import geko_options as geko_options_cls
from .transition_model_options import transition_model_options as transition_model_options_cls
from .transition_sst_option import transition_sst_option as transition_sst_option_cls
from .user_defined_2 import user_defined as user_defined_cls
from .sa_enhanced_wall_treatment import sa_enhanced_wall_treatment as sa_enhanced_wall_treatment_cls
from .sa_damping import sa_damping as sa_damping_cls
class viscous(Group):
    """
    'viscous' child.
    """

    fluent_name = "viscous"

    child_names = \
        ['model', 'options', 'spalart_allmaras_production', 'k_epsilon_model',
         'k_omega_model', 'k_omega_options', 'rng_options',
         'near_wall_treatment', 'reynolds_stress_model',
         'subgrid_scale_model', 'les_model_options',
         'reynolds_stress_options', 'rans_model', 'des_options',
         'transition_module', 'user_defined_transition',
         'multiphase_turbulence', 'turbulence_expert', 'geko_options',
         'transition_model_options', 'transition_sst_option', 'user_defined',
         'sa_enhanced_wall_treatment', 'sa_damping']

    model: model_cls = model_cls
    """
    model child of viscous.
    """
    options: options_cls = options_cls
    """
    options child of viscous.
    """
    spalart_allmaras_production: spalart_allmaras_production_cls = spalart_allmaras_production_cls
    """
    spalart_allmaras_production child of viscous.
    """
    k_epsilon_model: k_epsilon_model_cls = k_epsilon_model_cls
    """
    k_epsilon_model child of viscous.
    """
    k_omega_model: k_omega_model_cls = k_omega_model_cls
    """
    k_omega_model child of viscous.
    """
    k_omega_options: k_omega_options_cls = k_omega_options_cls
    """
    k_omega_options child of viscous.
    """
    rng_options: rng_options_cls = rng_options_cls
    """
    rng_options child of viscous.
    """
    near_wall_treatment: near_wall_treatment_cls = near_wall_treatment_cls
    """
    near_wall_treatment child of viscous.
    """
    reynolds_stress_model: reynolds_stress_model_cls = reynolds_stress_model_cls
    """
    reynolds_stress_model child of viscous.
    """
    subgrid_scale_model: subgrid_scale_model_cls = subgrid_scale_model_cls
    """
    subgrid_scale_model child of viscous.
    """
    les_model_options: les_model_options_cls = les_model_options_cls
    """
    les_model_options child of viscous.
    """
    reynolds_stress_options: reynolds_stress_options_cls = reynolds_stress_options_cls
    """
    reynolds_stress_options child of viscous.
    """
    rans_model: rans_model_cls = rans_model_cls
    """
    rans_model child of viscous.
    """
    des_options: des_options_cls = des_options_cls
    """
    des_options child of viscous.
    """
    transition_module: transition_module_cls = transition_module_cls
    """
    transition_module child of viscous.
    """
    user_defined_transition: user_defined_transition_cls = user_defined_transition_cls
    """
    user_defined_transition child of viscous.
    """
    multiphase_turbulence: multiphase_turbulence_cls = multiphase_turbulence_cls
    """
    multiphase_turbulence child of viscous.
    """
    turbulence_expert: turbulence_expert_cls = turbulence_expert_cls
    """
    turbulence_expert child of viscous.
    """
    geko_options: geko_options_cls = geko_options_cls
    """
    geko_options child of viscous.
    """
    transition_model_options: transition_model_options_cls = transition_model_options_cls
    """
    transition_model_options child of viscous.
    """
    transition_sst_option: transition_sst_option_cls = transition_sst_option_cls
    """
    transition_sst_option child of viscous.
    """
    user_defined: user_defined_cls = user_defined_cls
    """
    user_defined child of viscous.
    """
    sa_enhanced_wall_treatment: sa_enhanced_wall_treatment_cls = sa_enhanced_wall_treatment_cls
    """
    sa_enhanced_wall_treatment child of viscous.
    """
    sa_damping: sa_damping_cls = sa_damping_cls
    """
    sa_damping child of viscous.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .method_2 import method as method_cls
from .number_of_coeff import number_of_coeff as number_of_coeff_cls
from .function_of import function_of as function_of_cls
from .coefficients_1 import coefficients as coefficients_cls
from .value_1 import value as value_cls
from .piecewise_polynomial_1 import piecewise_polynomial as piecewise_polynomial_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
class hc(Group):
    """
    'hc' child.
    """

    fluent_name = "hc"

    child_names = \
        ['method', 'number_of_coeff', 'function_of', 'coefficients', 'value',
         'piecewise_polynomial', 'piecewise_linear']

    method: method_cls = method_cls
    """
    method child of hc.
    """
    number_of_coeff: number_of_coeff_cls = number_of_coeff_cls
    """
    number_of_coeff child of hc.
    """
    function_of: function_of_cls = function_of_cls
    """
    function_of child of hc.
    """
    coefficients: coefficients_cls = coefficients_cls
    """
    coefficients child of hc.
    """
    value: value_cls = value_cls
    """
    value child of hc.
    """
    piecewise_polynomial: piecewise_polynomial_cls = piecewise_polynomial_cls
    """
    piecewise_polynomial child of hc.
    """
    piecewise_linear: piecewise_linear_cls = piecewise_linear_cls
    """
    piecewise_linear child of hc.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .anode_alpha_a_2 import anode_alpha_a as anode_alpha_a_cls
from .anode_alpha_b import anode_alpha_b as anode_alpha_b_cls
from .cathode_alpha_a_2 import cathode_alpha_a as cathode_alpha_a_cls
from .cathode_alpha_b import cathode_alpha_b as cathode_alpha_b_cls
from .molef_ref_h2 import molef_ref_h2 as molef_ref_h2_cls
from .molef_ref_o2 import molef_ref_o2 as molef_ref_o2_cls
from .molef_ref_h2o import molef_ref_h2o as molef_ref_h2o_cls
from .exponent_h2 import exponent_h2 as exponent_h2_cls
from .exponent_o2 import exponent_o2 as exponent_o2_cls
from .exponent_h2o import exponent_h2o as exponent_h2o_cls
from .temp_depend_anode_i0 import temp_depend_anode_i0 as temp_depend_anode_i0_cls
from .temp_depend_cathode_i0 import temp_depend_cathode_i0 as temp_depend_cathode_i0_cls
from .anode_i0_2 import anode_i0 as anode_i0_cls
from .cathode_i0_2 import cathode_i0 as cathode_i0_cls
from .a_anode_i0 import a_anode_i0 as a_anode_i0_cls
from .b_anode_i0 import b_anode_i0 as b_anode_i0_cls
from .a_cathode_i0 import a_cathode_i0 as a_cathode_i0_cls
from .b_cathode_i0 import b_cathode_i0 as b_cathode_i0_cls
class electrochemistry(Group):
    """
    Electrochemistry.
    """

    fluent_name = "electrochemistry"

    child_names = \
        ['anode_alpha_a', 'anode_alpha_b', 'cathode_alpha_a',
         'cathode_alpha_b', 'molef_ref_h2', 'molef_ref_o2', 'molef_ref_h2o',
         'exponent_h2', 'exponent_o2', 'exponent_h2o', 'temp_depend_anode_i0',
         'temp_depend_cathode_i0', 'anode_i0', 'cathode_i0', 'a_anode_i0',
         'b_anode_i0', 'a_cathode_i0', 'b_cathode_i0']

    anode_alpha_a: anode_alpha_a_cls = anode_alpha_a_cls
    """
    anode_alpha_a child of electrochemistry.
    """
    anode_alpha_b: anode_alpha_b_cls = anode_alpha_b_cls
    """
    anode_alpha_b child of electrochemistry.
    """
    cathode_alpha_a: cathode_alpha_a_cls = cathode_alpha_a_cls
    """
    cathode_alpha_a child of electrochemistry.
    """
    cathode_alpha_b: cathode_alpha_b_cls = cathode_alpha_b_cls
    """
    cathode_alpha_b child of electrochemistry.
    """
    molef_ref_h2: molef_ref_h2_cls = molef_ref_h2_cls
    """
    molef_ref_h2 child of electrochemistry.
    """
    molef_ref_o2: molef_ref_o2_cls = molef_ref_o2_cls
    """
    molef_ref_o2 child of electrochemistry.
    """
    molef_ref_h2o: molef_ref_h2o_cls = molef_ref_h2o_cls
    """
    molef_ref_h2o child of electrochemistry.
    """
    exponent_h2: exponent_h2_cls = exponent_h2_cls
    """
    exponent_h2 child of electrochemistry.
    """
    exponent_o2: exponent_o2_cls = exponent_o2_cls
    """
    exponent_o2 child of electrochemistry.
    """
    exponent_h2o: exponent_h2o_cls = exponent_h2o_cls
    """
    exponent_h2o child of electrochemistry.
    """
    temp_depend_anode_i0: temp_depend_anode_i0_cls = temp_depend_anode_i0_cls
    """
    temp_depend_anode_i0 child of electrochemistry.
    """
    temp_depend_cathode_i0: temp_depend_cathode_i0_cls = temp_depend_cathode_i0_cls
    """
    temp_depend_cathode_i0 child of electrochemistry.
    """
    anode_i0: anode_i0_cls = anode_i0_cls
    """
    anode_i0 child of electrochemistry.
    """
    cathode_i0: cathode_i0_cls = cathode_i0_cls
    """
    cathode_i0 child of electrochemistry.
    """
    a_anode_i0: a_anode_i0_cls = a_anode_i0_cls
    """
    a_anode_i0 child of electrochemistry.
    """
    b_anode_i0: b_anode_i0_cls = b_anode_i0_cls
    """
    b_anode_i0 child of electrochemistry.
    """
    a_cathode_i0: a_cathode_i0_cls = a_cathode_i0_cls
    """
    a_cathode_i0 child of electrochemistry.
    """
    b_cathode_i0: b_cathode_i0_cls = b_cathode_i0_cls
    """
    b_cathode_i0 child of electrochemistry.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class recreate_all_shells(Command):
    """
    Create shell on all the walls where which were deleted using the command delete-all-shells.
    """

    fluent_name = "recreate-all-shells"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class use_face_normal_direction(Boolean, _HasAllowedValuesMixin):
    """
    'use_face_normal_direction' child.
    """

    fluent_name = "use-face-normal-direction?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class e_elastic_ne(Real):
    """
    Set Young's modulus of negative electrode (Pa).
    """

    fluent_name = "e-elastic-ne"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .headlight_setting import headlight_setting as headlight_setting_cls
from .lights_on import lights_on as lights_on_cls
from .lighting_interpolation import lighting_interpolation as lighting_interpolation_cls
from .set_ambient_color import set_ambient_color as set_ambient_color_cls
from .set_light import set_light as set_light_cls
class lights(Group):
    """
    'lights' child.
    """

    fluent_name = "lights"

    child_names = \
        ['headlight_setting', 'lights_on', 'lighting_interpolation']

    headlight_setting: headlight_setting_cls = headlight_setting_cls
    """
    headlight_setting child of lights.
    """
    lights_on: lights_on_cls = lights_on_cls
    """
    lights_on child of lights.
    """
    lighting_interpolation: lighting_interpolation_cls = lighting_interpolation_cls
    """
    lighting_interpolation child of lights.
    """
    command_names = \
        ['set_ambient_color', 'set_light']

    set_ambient_color: set_ambient_color_cls = set_ambient_color_cls
    """
    set_ambient_color command of lights.
    """
    set_light: set_light_cls = set_light_cls
    """
    set_light command of lights.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class time_scale_modification_method(Integer):
    """
    Set time scale modification method [0-time-step, 1-cfl].
    """

    fluent_name = "time-scale-modification-method"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .custom_vectors import custom_vectors as custom_vectors_cls
from .surfaces_5 import surfaces as surfaces_cls
from .graphics import graphics as graphics_cls
from .plot_6 import plot as plot_cls
from .scene import scene as scene_cls
from .animations import animations as animations_cls
from .report_1 import report as report_cls
class results(Group):
    """
    'results' child.
    """

    fluent_name = "results"

    child_names = \
        ['custom_vectors', 'surfaces', 'graphics', 'plot', 'scene',
         'animations', 'report']

    custom_vectors: custom_vectors_cls = custom_vectors_cls
    """
    custom_vectors child of results.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of results.
    """
    graphics: graphics_cls = graphics_cls
    """
    graphics child of results.
    """
    plot: plot_cls = plot_cls
    """
    plot child of results.
    """
    scene: scene_cls = scene_cls
    """
    scene child of results.
    """
    animations: animations_cls = animations_cls
    """
    animations child of results.
    """
    report: report_cls = report_cls
    """
    report child of results.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .binary_format import binary_format as binary_format_cls
from .surfaces import surfaces as surfaces_cls
from .cell_centered import cell_centered as cell_centered_cls
from .cell_function import cell_function as cell_function_cls
class ensight_gold_parallel_surfaces(Command):
    """
    Write EnSight Gold geometry, velocity and scalar files for surfaces. Fluent will write files suitable for EnSight Parallel.
    
    Parameters
    ----------
        name : str
            'name' child.
        binary_format : bool
            'binary_format' child.
        surfaces : typing.List[str]
            'surfaces' child.
        cell_centered : bool
            'cell_centered' child.
        cell_function : typing.List[str]
            'cell_function' child.
    
    """

    fluent_name = "ensight-gold-parallel-surfaces"

    argument_names = \
        ['name', 'binary_format', 'surfaces', 'cell_centered',
         'cell_function']

    name: name_cls = name_cls
    """
    name argument of ensight_gold_parallel_surfaces.
    """
    binary_format: binary_format_cls = binary_format_cls
    """
    binary_format argument of ensight_gold_parallel_surfaces.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces argument of ensight_gold_parallel_surfaces.
    """
    cell_centered: cell_centered_cls = cell_centered_cls
    """
    cell_centered argument of ensight_gold_parallel_surfaces.
    """
    cell_function: cell_function_cls = cell_function_cls
    """
    cell_function argument of ensight_gold_parallel_surfaces.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_9 import option as option_cls
from .value import value as value_cls
from .user_defined_function import user_defined_function as user_defined_function_cls
class charge_density(Group):
    """
    'charge_density' child.
    """

    fluent_name = "charge-density"

    child_names = \
        ['option', 'value', 'user_defined_function']

    option: option_cls = option_cls
    """
    option child of charge_density.
    """
    value: value_cls = value_cls
    """
    value child of charge_density.
    """
    user_defined_function: user_defined_function_cls = user_defined_function_cls
    """
    user_defined_function child of charge_density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_partition_method import file_partition_method as file_partition_method_cls
class use_case_file_method(Command):
    """
    Enable the use-case-file method for auto partitioning.
    
    Parameters
    ----------
        file_partition_method : bool
            'file_partition_method' child.
    
    """

    fluent_name = "use-case-file-method"

    argument_names = \
        ['file_partition_method']

    file_partition_method: file_partition_method_cls = file_partition_method_cls
    """
    file_partition_method argument of use_case_file_method.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class maximum_udf_species(Integer):
    """
    Specify the maximum number of species that can be used in DPM UDFs.
    """

    fluent_name = "maximum-udf-species"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .minimum_1 import minimum as minimum_cls
from .maximum_1 import maximum as maximum_cls
from .number_of_coeff import number_of_coeff as number_of_coeff_cls
from .coefficients_1 import coefficients as coefficients_cls
class piecewise_polynomial_child(Group):
    """
    'child_object_type' of piecewise_polynomial.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['minimum', 'maximum', 'number_of_coeff', 'coefficients']

    minimum: minimum_cls = minimum_cls
    """
    minimum child of piecewise_polynomial_child.
    """
    maximum: maximum_cls = maximum_cls
    """
    maximum child of piecewise_polynomial_child.
    """
    number_of_coeff: number_of_coeff_cls = number_of_coeff_cls
    """
    number_of_coeff child of piecewise_polynomial_child.
    """
    coefficients: coefficients_cls = coefficients_cls
    """
    coefficients child of piecewise_polynomial_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class only_list_case_boundaries(Boolean):
    """
    Only list the boundary types that are assigned in this case.
    """

    fluent_name = "only-list-case-boundaries?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .terminology import terminology as terminology_cls
from .disk_normal_x import disk_normal_x as disk_normal_x_cls
from .disk_normal_y import disk_normal_y as disk_normal_y_cls
from .disk_normal_z import disk_normal_z as disk_normal_z_cls
from .disk_pitch_angle import disk_pitch_angle as disk_pitch_angle_cls
from .disk_bank_angle import disk_bank_angle as disk_bank_angle_cls
class disk_orientation(Group):
    """
    Menu to define the rotor disk orientation.
    
     - terminology      : the terminology to specify the rotor disk orientation: rotor-disk-angles / rotor-disk-normal, 
     - disk-normal-x/yz : rotor-disk-normal components, 
     - disk-pitch-angle : , 
     - disk-bank-angle : , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "disk-orientation"

    child_names = \
        ['terminology', 'disk_normal_x', 'disk_normal_y', 'disk_normal_z',
         'disk_pitch_angle', 'disk_bank_angle']

    terminology: terminology_cls = terminology_cls
    """
    terminology child of disk_orientation.
    """
    disk_normal_x: disk_normal_x_cls = disk_normal_x_cls
    """
    disk_normal_x child of disk_orientation.
    """
    disk_normal_y: disk_normal_y_cls = disk_normal_y_cls
    """
    disk_normal_y child of disk_orientation.
    """
    disk_normal_z: disk_normal_z_cls = disk_normal_z_cls
    """
    disk_normal_z child of disk_orientation.
    """
    disk_pitch_angle: disk_pitch_angle_cls = disk_pitch_angle_cls
    """
    disk_pitch_angle child of disk_orientation.
    """
    disk_bank_angle: disk_bank_angle_cls = disk_bank_angle_cls
    """
    disk_bank_angle child of disk_orientation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .parallel_verbosity_level import parallel_verbosity_level as parallel_verbosity_level_cls
from .crossover_tolerance import crossover_tolerance as crossover_tolerance_cls
class expert_options(Group):
    """
    'expert_options' child.
    """

    fluent_name = "expert-options"

    child_names = \
        ['parallel_verbosity_level', 'crossover_tolerance']

    parallel_verbosity_level: parallel_verbosity_level_cls = parallel_verbosity_level_cls
    """
    parallel_verbosity_level child of expert_options.
    """
    crossover_tolerance: crossover_tolerance_cls = crossover_tolerance_cls
    """
    crossover_tolerance child of expert_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .auto_range_on import auto_range_on as auto_range_on_cls
from .auto_range_off import auto_range_off as auto_range_off_cls
class range_option(Group):
    """
    'range_option' child.
    """

    fluent_name = "range-option"

    child_names = \
        ['option', 'auto_range_on', 'auto_range_off']

    option: option_cls = option_cls
    """
    option child of range_option.
    """
    auto_range_on: auto_range_on_cls = auto_range_on_cls
    """
    auto_range_on child of range_option.
    """
    auto_range_off: auto_range_off_cls = auto_range_off_cls
    """
    auto_range_off child of range_option.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .center import center as center_cls
from .radius import radius as radius_cls
from .inside import inside as inside_cls
from .create_volume_surface import create_volume_surface as create_volume_surface_cls
class sphere(Group):
    """
    'sphere' child.
    """

    fluent_name = "sphere"

    child_names = \
        ['center', 'radius', 'inside', 'create_volume_surface']

    center: center_cls = center_cls
    """
    center child of sphere.
    """
    radius: radius_cls = radius_cls
    """
    radius child of sphere.
    """
    inside: inside_cls = inside_cls
    """
    inside child of sphere.
    """
    create_volume_surface: create_volume_surface_cls = create_volume_surface_cls
    """
    create_volume_surface child of sphere.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cathode_cc_zone_list import cathode_cc_zone_list as cathode_cc_zone_list_cls
from .cathode_cc_update import cathode_cc_update as cathode_cc_update_cls
from .cathode_cc_material import cathode_cc_material as cathode_cc_material_cls
class cathode_cc_zone(Group):
    """
    'cathode_cc_zone' child.
    """

    fluent_name = "cathode-cc-zone"

    child_names = \
        ['cathode_cc_zone_list', 'cathode_cc_update', 'cathode_cc_material']

    cathode_cc_zone_list: cathode_cc_zone_list_cls = cathode_cc_zone_list_cls
    """
    cathode_cc_zone_list child of cathode_cc_zone.
    """
    cathode_cc_update: cathode_cc_update_cls = cathode_cc_update_cls
    """
    cathode_cc_update child of cathode_cc_zone.
    """
    cathode_cc_material: cathode_cc_material_cls = cathode_cc_material_cls
    """
    cathode_cc_material child of cathode_cc_zone.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .face_zone_name import face_zone_name as face_zone_name_cls
from .register_name import register_name as register_name_cls
from .move_faces import move_faces as move_faces_cls
class sep_face_zone_mark(Command):
    """
    Separate a face zone based on cell marking.
    
    Parameters
    ----------
        face_zone_name : str
            Enter a zone name.
        register_name : str
            'register_name' child.
        move_faces : bool
            'move_faces' child.
    
    """

    fluent_name = "sep-face-zone-mark"

    argument_names = \
        ['face_zone_name', 'register_name', 'move_faces']

    face_zone_name: face_zone_name_cls = face_zone_name_cls
    """
    face_zone_name argument of sep_face_zone_mark.
    """
    register_name: register_name_cls = register_name_cls
    """
    register_name argument of sep_face_zone_mark.
    """
    move_faces: move_faces_cls = move_faces_cls
    """
    move_faces argument of sep_face_zone_mark.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density import density as density_cls
from .viscosity import viscosity as viscosity_cls
from .specific_heat import specific_heat as specific_heat_cls
from .thermal_conductivity import thermal_conductivity as thermal_conductivity_cls
from .molecular_weight import molecular_weight as molecular_weight_cls
from .premix_laminar_speed import premix_laminar_speed as premix_laminar_speed_cls
from .premix_critical_strain import premix_critical_strain as premix_critical_strain_cls
from .premix_unburnt_temp import premix_unburnt_temp as premix_unburnt_temp_cls
from .premix_unburnt_density import premix_unburnt_density as premix_unburnt_density_cls
from .premix_heat_trans_coeff import premix_heat_trans_coeff as premix_heat_trans_coeff_cls
from .premix_heat_of_comb import premix_heat_of_comb as premix_heat_of_comb_cls
from .premix_unburnt_fuel_mf import premix_unburnt_fuel_mf as premix_unburnt_fuel_mf_cls
from .premix_adiabatic_temp import premix_adiabatic_temp as premix_adiabatic_temp_cls
from .therm_exp_coeff import therm_exp_coeff as therm_exp_coeff_cls
from .characteristic_vibrational_temperature import characteristic_vibrational_temperature as characteristic_vibrational_temperature_cls
from .absorption_coefficient import absorption_coefficient as absorption_coefficient_cls
from .melting_heat import melting_heat as melting_heat_cls
from .tsolidus import tsolidus as tsolidus_cls
from .tliqidus import tliqidus as tliqidus_cls
from .liquidus_slope import liquidus_slope as liquidus_slope_cls
from .partition_coeff import partition_coeff as partition_coeff_cls
from .eutectic_mf import eutectic_mf as eutectic_mf_cls
from .solid_diffusion import solid_diffusion as solid_diffusion_cls
from .solut_exp_coeff import solut_exp_coeff as solut_exp_coeff_cls
from .scattering_coefficient import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .refractive_index import refractive_index as refractive_index_cls
from .formation_entropy import formation_entropy as formation_entropy_cls
from .formation_enthalpy import formation_enthalpy as formation_enthalpy_cls
from .reference_temperature_1 import reference_temperature as reference_temperature_cls
from .lennard_jones_length import lennard_jones_length as lennard_jones_length_cls
from .lennard_jones_energy import lennard_jones_energy as lennard_jones_energy_cls
from .thermal_accom_coefficient import thermal_accom_coefficient as thermal_accom_coefficient_cls
from .velocity_accom_coefficient import velocity_accom_coefficient as velocity_accom_coefficient_cls
from .degrees_of_freedom import degrees_of_freedom as degrees_of_freedom_cls
from .uds_diffusivity import uds_diffusivity as uds_diffusivity_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .speed_of_sound import speed_of_sound as speed_of_sound_cls
from .critical_temperature import critical_temperature as critical_temperature_cls
from .critical_pressure import critical_pressure as critical_pressure_cls
from .critical_volume import critical_volume as critical_volume_cls
from .acentric_factor import acentric_factor as acentric_factor_cls
from .latent_heat import latent_heat as latent_heat_cls
from .saturation_pressure import saturation_pressure as saturation_pressure_cls
from .vaporization_temperature import vaporization_temperature as vaporization_temperature_cls
from .charge import charge as charge_cls
class fluid_child(Group):
    """
    'child_object_type' of fluid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'viscosity', 'specific_heat',
         'thermal_conductivity', 'molecular_weight', 'premix_laminar_speed',
         'premix_critical_strain', 'premix_unburnt_temp',
         'premix_unburnt_density', 'premix_heat_trans_coeff',
         'premix_heat_of_comb', 'premix_unburnt_fuel_mf',
         'premix_adiabatic_temp', 'therm_exp_coeff',
         'characteristic_vibrational_temperature', 'absorption_coefficient',
         'melting_heat', 'tsolidus', 'tliqidus', 'liquidus_slope',
         'partition_coeff', 'eutectic_mf', 'solid_diffusion',
         'solut_exp_coeff', 'scattering_coefficient',
         'scattering_phase_function', 'refractive_index', 'formation_entropy',
         'formation_enthalpy', 'reference_temperature',
         'lennard_jones_length', 'lennard_jones_energy',
         'thermal_accom_coefficient', 'velocity_accom_coefficient',
         'degrees_of_freedom', 'uds_diffusivity', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'magnetic_permeability', 'speed_of_sound', 'critical_temperature',
         'critical_pressure', 'critical_volume', 'acentric_factor',
         'latent_heat', 'saturation_pressure', 'vaporization_temperature',
         'charge']

    name: name_cls = name_cls
    """
    name child of fluid_child.
    """
    chemical_formula: chemical_formula_cls = chemical_formula_cls
    """
    chemical_formula child of fluid_child.
    """
    density: density_cls = density_cls
    """
    density child of fluid_child.
    """
    viscosity: viscosity_cls = viscosity_cls
    """
    viscosity child of fluid_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of fluid_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of fluid_child.
    """
    molecular_weight: molecular_weight_cls = molecular_weight_cls
    """
    molecular_weight child of fluid_child.
    """
    premix_laminar_speed: premix_laminar_speed_cls = premix_laminar_speed_cls
    """
    premix_laminar_speed child of fluid_child.
    """
    premix_critical_strain: premix_critical_strain_cls = premix_critical_strain_cls
    """
    premix_critical_strain child of fluid_child.
    """
    premix_unburnt_temp: premix_unburnt_temp_cls = premix_unburnt_temp_cls
    """
    premix_unburnt_temp child of fluid_child.
    """
    premix_unburnt_density: premix_unburnt_density_cls = premix_unburnt_density_cls
    """
    premix_unburnt_density child of fluid_child.
    """
    premix_heat_trans_coeff: premix_heat_trans_coeff_cls = premix_heat_trans_coeff_cls
    """
    premix_heat_trans_coeff child of fluid_child.
    """
    premix_heat_of_comb: premix_heat_of_comb_cls = premix_heat_of_comb_cls
    """
    premix_heat_of_comb child of fluid_child.
    """
    premix_unburnt_fuel_mf: premix_unburnt_fuel_mf_cls = premix_unburnt_fuel_mf_cls
    """
    premix_unburnt_fuel_mf child of fluid_child.
    """
    premix_adiabatic_temp: premix_adiabatic_temp_cls = premix_adiabatic_temp_cls
    """
    premix_adiabatic_temp child of fluid_child.
    """
    therm_exp_coeff: therm_exp_coeff_cls = therm_exp_coeff_cls
    """
    therm_exp_coeff child of fluid_child.
    """
    characteristic_vibrational_temperature: characteristic_vibrational_temperature_cls = characteristic_vibrational_temperature_cls
    """
    characteristic_vibrational_temperature child of fluid_child.
    """
    absorption_coefficient: absorption_coefficient_cls = absorption_coefficient_cls
    """
    absorption_coefficient child of fluid_child.
    """
    melting_heat: melting_heat_cls = melting_heat_cls
    """
    melting_heat child of fluid_child.
    """
    tsolidus: tsolidus_cls = tsolidus_cls
    """
    tsolidus child of fluid_child.
    """
    tliqidus: tliqidus_cls = tliqidus_cls
    """
    tliqidus child of fluid_child.
    """
    liquidus_slope: liquidus_slope_cls = liquidus_slope_cls
    """
    liquidus_slope child of fluid_child.
    """
    partition_coeff: partition_coeff_cls = partition_coeff_cls
    """
    partition_coeff child of fluid_child.
    """
    eutectic_mf: eutectic_mf_cls = eutectic_mf_cls
    """
    eutectic_mf child of fluid_child.
    """
    solid_diffusion: solid_diffusion_cls = solid_diffusion_cls
    """
    solid_diffusion child of fluid_child.
    """
    solut_exp_coeff: solut_exp_coeff_cls = solut_exp_coeff_cls
    """
    solut_exp_coeff child of fluid_child.
    """
    scattering_coefficient: scattering_coefficient_cls = scattering_coefficient_cls
    """
    scattering_coefficient child of fluid_child.
    """
    scattering_phase_function: scattering_phase_function_cls = scattering_phase_function_cls
    """
    scattering_phase_function child of fluid_child.
    """
    refractive_index: refractive_index_cls = refractive_index_cls
    """
    refractive_index child of fluid_child.
    """
    formation_entropy: formation_entropy_cls = formation_entropy_cls
    """
    formation_entropy child of fluid_child.
    """
    formation_enthalpy: formation_enthalpy_cls = formation_enthalpy_cls
    """
    formation_enthalpy child of fluid_child.
    """
    reference_temperature: reference_temperature_cls = reference_temperature_cls
    """
    reference_temperature child of fluid_child.
    """
    lennard_jones_length: lennard_jones_length_cls = lennard_jones_length_cls
    """
    lennard_jones_length child of fluid_child.
    """
    lennard_jones_energy: lennard_jones_energy_cls = lennard_jones_energy_cls
    """
    lennard_jones_energy child of fluid_child.
    """
    thermal_accom_coefficient: thermal_accom_coefficient_cls = thermal_accom_coefficient_cls
    """
    thermal_accom_coefficient child of fluid_child.
    """
    velocity_accom_coefficient: velocity_accom_coefficient_cls = velocity_accom_coefficient_cls
    """
    velocity_accom_coefficient child of fluid_child.
    """
    degrees_of_freedom: degrees_of_freedom_cls = degrees_of_freedom_cls
    """
    degrees_of_freedom child of fluid_child.
    """
    uds_diffusivity: uds_diffusivity_cls = uds_diffusivity_cls
    """
    uds_diffusivity child of fluid_child.
    """
    electric_conductivity: electric_conductivity_cls = electric_conductivity_cls
    """
    electric_conductivity child of fluid_child.
    """
    dual_electric_conductivity: dual_electric_conductivity_cls = dual_electric_conductivity_cls
    """
    dual_electric_conductivity child of fluid_child.
    """
    lithium_diffusivity: lithium_diffusivity_cls = lithium_diffusivity_cls
    """
    lithium_diffusivity child of fluid_child.
    """
    magnetic_permeability: magnetic_permeability_cls = magnetic_permeability_cls
    """
    magnetic_permeability child of fluid_child.
    """
    speed_of_sound: speed_of_sound_cls = speed_of_sound_cls
    """
    speed_of_sound child of fluid_child.
    """
    critical_temperature: critical_temperature_cls = critical_temperature_cls
    """
    critical_temperature child of fluid_child.
    """
    critical_pressure: critical_pressure_cls = critical_pressure_cls
    """
    critical_pressure child of fluid_child.
    """
    critical_volume: critical_volume_cls = critical_volume_cls
    """
    critical_volume child of fluid_child.
    """
    acentric_factor: acentric_factor_cls = acentric_factor_cls
    """
    acentric_factor child of fluid_child.
    """
    latent_heat: latent_heat_cls = latent_heat_cls
    """
    latent_heat child of fluid_child.
    """
    saturation_pressure: saturation_pressure_cls = saturation_pressure_cls
    """
    saturation_pressure child of fluid_child.
    """
    vaporization_temperature: vaporization_temperature_cls = vaporization_temperature_cls
    """
    vaporization_temperature child of fluid_child.
    """
    charge: charge_cls = charge_cls
    """
    charge child of fluid_child.
    """



"""Module providing visualization objects definition."""
from abc import abstractmethod
import logging
from typing import List, NamedTuple, Optional

from ansys.fluent.core.meta import (
    Attribute,
    PyLocalNamedObjectMetaAbstract,
    PyLocalObjectMeta,
    PyLocalPropertyMeta,
)

logger = logging.getLogger("pyfluent.post_objects")


class BasePostObjectDefn:
    """Base class for visualization objects."""

    def _pre_display(self):
        local_surfaces_provider = self.get_root()._local_surfaces_provider()
        for surf_name in self.surfaces_list():
            if surf_name in list(local_surfaces_provider):
                surf_obj = local_surfaces_provider[surf_name]
                surf_api = surf_obj._api_helper.surface_api
                surf_api.create_surface_on_server()

    def _post_display(self):
        local_surfaces_provider = self.get_root()._local_surfaces_provider()
        for surf_name in self.surfaces_list():
            if surf_name in list(local_surfaces_provider):
                surf_obj = local_surfaces_provider[surf_name]
                surf_api = surf_obj._api_helper.surface_api
                surf_api.delete_surface_on_server()


class GraphicsDefn(BasePostObjectDefn, metaclass=PyLocalNamedObjectMetaAbstract):
    """Abstract base class for graphics objects."""

    @abstractmethod
    def display(self, window_id: Optional[str] = None):
        """Display graphics.

        Parameters
        ----------
        window_id : str, optional
            Window ID. If not specified, unique ID is used.
        """
        pass


class PlotDefn(BasePostObjectDefn, metaclass=PyLocalNamedObjectMetaAbstract):
    """Abstract base class for plot objects."""

    @abstractmethod
    def plot(self, window_id: Optional[str] = None):
        """Draw plot.

        Parameters
        ----------
        window_id : str, optional
            Window ID. If not specified, unique ID is used.
        """
        pass


class Vector(NamedTuple):
    """Class for vector definition."""

    x: float
    y: float
    z: float


class MonitorDefn(PlotDefn):
    """Monitor Definition."""

    PLURAL = "Monitors"

    class monitor_set_name(metaclass=PyLocalPropertyMeta):
        """Monitor set name."""

        value: str = None

        @Attribute
        def allowed_values(self):
            """Monitor set allowed values."""
            return self._api_helper.monitors_manager().get_monitor_set_names()


class XYPlotDefn(PlotDefn):
    """XYPlot Definition."""

    PLURAL = "XYPlots"

    class node_values(metaclass=PyLocalPropertyMeta):
        """Plot nodal values."""

        value: bool = True

    class boundary_values(metaclass=PyLocalPropertyMeta):
        """Plot Boundary values."""

        value: bool = True

    class direction_vector(metaclass=PyLocalPropertyMeta):
        """Direction Vector."""

        value: Vector = [1, 0, 0]

    class y_axis_function(metaclass=PyLocalPropertyMeta):
        """Y Axis Function."""

        value: str = None

        @Attribute
        def allowed_values(self):
            """Y axis function allowed values."""
            return list(self._api_helper.field_info().get_scalar_fields_info())

    class x_axis_function(metaclass=PyLocalPropertyMeta):
        """X Axis Function."""

        value: str = "direction-vector"

        @Attribute
        def allowed_values(self):
            """X axis function allowed values."""
            return ["direction-vector"]

    class surfaces_list(metaclass=PyLocalPropertyMeta):
        """List of surfaces for plotting."""

        value: List[str] = []

        @Attribute
        def allowed_values(self):
            """Surface list allowed values."""
            return list(
                self._api_helper.field_info().get_surfaces_info().keys()
            ) + list(self.get_root()._local_surfaces_provider())


class MeshDefn(GraphicsDefn):
    """Mesh graphics definition."""

    PLURAL = "Meshes"

    class surfaces_list(metaclass=PyLocalPropertyMeta):
        """List of surfaces for mesh graphics."""

        value: List[str] = []

        @Attribute
        def allowed_values(self):
            """Surface list allowed values."""
            return list(
                (self._api_helper.field_info().get_surfaces_info().keys())
            ) + list(self.get_root()._local_surfaces_provider())

    class show_edges(metaclass=PyLocalPropertyMeta):
        """Show edges for mesh."""

        value: bool = False

    class show_nodes(metaclass=PyLocalPropertyMeta):
        """Show nodes for mesh."""

        value: bool = False

    class show_faces(metaclass=PyLocalPropertyMeta):
        """Show faces for mesh."""

        value: bool = True


class PathlinesDefn(GraphicsDefn):
    """Pathlines definition."""

    PLURAL = "Pathlines"

    class field(metaclass=PyLocalPropertyMeta):
        """Pathlines field."""

        value: str = None

        @Attribute
        def allowed_values(self):
            """Field allowed values."""
            return list(self._api_helper.field_info().get_scalar_fields_info())

    class surfaces_list(metaclass=PyLocalPropertyMeta):
        """List of surfaces for pathlines."""

        value: List[str] = []

        @Attribute
        def allowed_values(self):
            """Surface list allowed values."""
            return list(
                (self._api_helper.field_info().get_surfaces_info().keys())
            ) + list(self.get_root()._local_surfaces_provider())


class SurfaceDefn(GraphicsDefn):
    """Surface graphics definition."""

    PLURAL = "Surfaces"

    class show_edges(metaclass=PyLocalPropertyMeta):
        """Show edges for surface."""

        value: bool = True

    class definition(metaclass=PyLocalObjectMeta):
        """Specify surface definition type."""

        class type(metaclass=PyLocalPropertyMeta):
            """Surface type."""

            value: str = "iso-surface"

            @Attribute
            def allowed_values(self):
                """Surface type allowed values."""
                return ["plane-surface", "iso-surface"]

        class plane_surface(metaclass=PyLocalObjectMeta):
            """Plane surface definition."""

            @Attribute
            def is_active(self):
                return self._parent.type() == "plane-surface"

            class creation_method(metaclass=PyLocalPropertyMeta):
                """Creation Method."""

                value: str = "xy-plane"

                @Attribute
                def allowed_values(self):
                    """Surface type allowed values."""
                    return ["xy-plane", "yz-plane", "zx-plane"]

            class xy_plane(metaclass=PyLocalObjectMeta):
                """XY Plane definition."""

                @Attribute
                def is_active(self):
                    return self._parent.creation_method() == "xy-plane"

                class z(metaclass=PyLocalPropertyMeta):
                    """Z value."""

                    value: float = 0

                    @Attribute
                    def range(self):
                        """Z value range."""
                        return self._api_helper.field_info().get_scalar_field_range(
                            "z-coordinate", True
                        )

            class yz_plane(metaclass=PyLocalObjectMeta):
                """YZ Plane definition."""

                @Attribute
                def is_active(self):
                    return self._parent.creation_method() == "yz-plane"

                class x(metaclass=PyLocalPropertyMeta):
                    """X value."""

                    value: float = 0

                    @Attribute
                    def range(self):
                        """X value range."""
                        return self._api_helper.field_info().get_scalar_field_range(
                            "x-coordinate", True
                        )

            class zx_plane(metaclass=PyLocalObjectMeta):
                """ZX Plane definition."""

                @Attribute
                def is_active(self):
                    return self._parent.creation_method() == "zx-plane"

                class y(metaclass=PyLocalPropertyMeta):
                    """Y value."""

                    value: float = 0

                    @Attribute
                    def range(self):
                        """Y value range."""
                        return self._api_helper.field_info().get_scalar_field_range(
                            "y-coordinate", True
                        )

        class iso_surface(metaclass=PyLocalObjectMeta):
            """Iso surface definition."""

            @Attribute
            def is_active(self):
                return self._parent.type() == "iso-surface"

            class field(metaclass=PyLocalPropertyMeta):
                """Iso surface field."""

                value: str = None

                @Attribute
                def allowed_values(self):
                    """Field allowed values."""
                    return list(self._api_helper.field_info().get_scalar_fields_info())

            class rendering(metaclass=PyLocalPropertyMeta):
                """Iso surface rendering."""

                value: str = "mesh"

                @Attribute
                def allowed_values(self):
                    """Surface rendering allowed values."""
                    return ["mesh", "contour"]

            class iso_value(metaclass=PyLocalPropertyMeta):
                """Iso value for field."""

                _value: float = None

                def _reset_on_change(self):
                    return [self._parent.field]

                @property
                def value(self):
                    """Iso value property setter."""
                    if getattr(self, "_value", None) is None:
                        rnge = self.range
                        self._value = (rnge[0] + rnge[1]) / 2.0 if rnge else None
                    return self._value

                @value.setter
                def value(self, value):
                    self._value = value

                @Attribute
                def range(self):
                    """Iso value range."""
                    field = self._parent.field()
                    if field:
                        return self._api_helper.field_info().get_scalar_field_range(
                            field, True
                        )


class ContourDefn(GraphicsDefn):
    """Contour graphics definition."""

    PLURAL = "Contours"

    class field(metaclass=PyLocalPropertyMeta):
        """Contour field."""

        value: str = None

        @Attribute
        def allowed_values(self):
            """Field allowed values."""
            return list(self._api_helper.field_info().get_scalar_fields_info())

    class surfaces_list(metaclass=PyLocalPropertyMeta):
        """Contour surfaces."""

        value: List[str] = []

        @Attribute
        def allowed_values(self):
            """Surfaces list allowed values."""
            return list(
                self._api_helper.field_info().get_surfaces_info().keys()
            ) + list(self.get_root()._local_surfaces_provider())

    class filled(metaclass=PyLocalPropertyMeta):
        """Draw filled contour."""

        value: bool = True

    class node_values(metaclass=PyLocalPropertyMeta):
        """Draw nodal data."""

        _value: bool = True

        @property
        def value(self):
            """Node value property setter."""
            filled = self.get_ancestors_by_type(ContourDefn).filled()
            auto_range_off = self.get_ancestors_by_type(
                ContourDefn
            ).range.auto_range_off
            if not filled or (auto_range_off and auto_range_off.clip_to_range()):
                logger.warning(
                    "For unfilled and clipped contours node values are displayed."
                )
                self._value = True
            return self._value

        @value.setter
        def value(self, value):
            self._value = value

    class boundary_values(metaclass=PyLocalPropertyMeta):
        """Draw boundary values."""

        value: bool = False

    class contour_lines(metaclass=PyLocalPropertyMeta):
        """Draw contour lines."""

        value: bool = False

    class show_edges(metaclass=PyLocalPropertyMeta):
        """Show edges."""

        value: bool = False

    class range(metaclass=PyLocalObjectMeta):
        """Range definition."""

        class option(metaclass=PyLocalPropertyMeta):
            """Range option."""

            value: str = "auto-range-on"

            @Attribute
            def allowed_values(self):
                """Range option allowed values."""
                return ["auto-range-on", "auto-range-off"]

        class auto_range_on(metaclass=PyLocalObjectMeta):
            """Auto range on definition."""

            @Attribute
            def is_active(self):
                return self._parent.option() == "auto-range-on"

            class global_range(metaclass=PyLocalPropertyMeta):
                """Show global range."""

                value: bool = False

        class auto_range_off(metaclass=PyLocalObjectMeta):
            """Auto range off definition."""

            @Attribute
            def is_active(self):
                return self._parent.option() == "auto-range-off"

            class clip_to_range(metaclass=PyLocalPropertyMeta):
                """Clip contour within range."""

                value: bool = False

            class minimum(metaclass=PyLocalPropertyMeta):
                """Range minimum."""

                _value: float = None

                def _reset_on_change(self):
                    return [
                        self.get_ancestors_by_type(ContourDefn).field,
                        self.get_ancestors_by_type(ContourDefn).node_values,
                    ]

                @property
                def value(self):
                    """Range minimum property setter."""
                    if getattr(self, "_value", None) is None:
                        field = self.get_ancestors_by_type(ContourDefn).field()
                        if field:
                            field_info = self._api_helper.field_info()
                            field_range = field_info.get_scalar_field_range(
                                field,
                                self.get_ancestors_by_type(ContourDefn).node_values(),
                            )
                            self._value = field_range[0]
                    return self._value

                @value.setter
                def value(self, value):
                    self._value = value

            class maximum(metaclass=PyLocalPropertyMeta):
                """Range maximum."""

                _value: float = None

                def _reset_on_change(self):
                    return [
                        self.get_ancestors_by_type(ContourDefn).field,
                        self.get_ancestors_by_type(ContourDefn).node_values,
                    ]

                @property
                def value(self):
                    """Range maximum property setter."""
                    if getattr(self, "_value", None) is None:
                        field = self.get_ancestors_by_type(ContourDefn).field()
                        if field:
                            field_info = self._api_helper.field_info()
                            field_range = field_info.get_scalar_field_range(
                                field,
                                self.get_ancestors_by_type(ContourDefn).node_values(),
                            )
                            self._value = field_range[1]

                    return self._value

                @value.setter
                def value(self, value):
                    self._value = value


class VectorDefn(GraphicsDefn):
    """Vector graphics definition."""

    PLURAL = "Vectors"

    class vectors_of(metaclass=PyLocalPropertyMeta):
        """Vector type."""

        value: str = "velocity"

        @Attribute
        def allowed_values(self):
            """Vectors of allowed values."""
            if hasattr(self._api_helper.field_info(), "get_vector_fields_info"):
                return list(self._api_helper.field_info().get_vector_fields_info())
            return list(self._api_helper.get_vector_fields())

    class field(metaclass=PyLocalPropertyMeta):
        """Vector color field."""

        value: str = None

        @Attribute
        def allowed_values(self):
            """Field allowed values."""
            return list(self._api_helper.field_info().get_scalar_fields_info())

    class surfaces_list(metaclass=PyLocalPropertyMeta):
        """List of surfaces for vector graphics."""

        value: List[str] = []

        @Attribute
        def allowed_values(self):
            """Surface list allowed values."""
            return list(
                self._api_helper.field_info().get_surfaces_info().keys()
            ) + list(self.get_root()._local_surfaces_provider())

    class scale(metaclass=PyLocalPropertyMeta):
        """Vector scale."""

        value: float = 1.0

    class skip(metaclass=PyLocalPropertyMeta):
        """Vector skip."""

        value: int = 0

    class show_edges(metaclass=PyLocalPropertyMeta):
        """Show edges."""

        value: bool = False

    class range(metaclass=PyLocalObjectMeta):
        """Range definition."""

        class option(metaclass=PyLocalPropertyMeta):
            """Range option."""

            value: str = "auto-range-on"

            @Attribute
            def allowed_values(self):
                """Range option allowed values."""
                return ["auto-range-on", "auto-range-off"]

        class auto_range_on(metaclass=PyLocalObjectMeta):
            """Auto range on definition."""

            @Attribute
            def is_active(self):
                return self._parent.option() == "auto-range-on"

            class global_range(metaclass=PyLocalPropertyMeta):
                """Show global range."""

                value: bool = False

        class auto_range_off(metaclass=PyLocalObjectMeta):
            """Auto range off definition."""

            @Attribute
            def is_active(self):
                return self._parent.option() == "auto-range-off"

            class clip_to_range(metaclass=PyLocalPropertyMeta):
                """Clip vector within range."""

                value: bool = False

            class minimum(metaclass=PyLocalPropertyMeta):
                """Range minimum."""

                _value: float = None

                @property
                def value(self):
                    """Range minimum property setter."""
                    if getattr(self, "_value", None) is None:
                        field_info = self._api_helper.field_info()
                        field_range = field_info.get_scalar_field_range(
                            "velocity-magnitude",
                            False,
                        )
                        self._value = field_range[0]
                    return self._value

                @value.setter
                def value(self, value):
                    self._value = value

            class maximum(metaclass=PyLocalPropertyMeta):
                """Range maximum."""

                _value: float = None

                @property
                def value(self):
                    """Range maximum property setter."""
                    if getattr(self, "_value", None) is None:
                        field_info = self._api_helper.field_info()
                        field_range = field_info.get_scalar_field_range(
                            "velocity-magnitude",
                            False,
                        )
                        self._value = field_range[1]
                    return self._value

                @value.setter
                def value(self, value):
                    self._value = value



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .heat_of_surface_reactions import heat_of_surface_reactions as heat_of_surface_reactions_cls
from .mass_deposition_source import mass_deposition_source as mass_deposition_source_cls
from .reaction_diffusion_balance import reaction_diffusion_balance as reaction_diffusion_balance_cls
from .surface_reaction_aggresiveness_factor import surface_reaction_aggresiveness_factor as surface_reaction_aggresiveness_factor_cls
from .surface_reaction_rate_temperature_factor import surface_reaction_rate_temperature_factor as surface_reaction_rate_temperature_factor_cls
from .surface_reaction_solid_fraction import surface_reaction_solid_fraction as surface_reaction_solid_fraction_cls
class wall_surface_options(Group):
    """
    'wall_surface_options' child.
    """

    fluent_name = "wall-surface-options"

    child_names = \
        ['heat_of_surface_reactions', 'mass_deposition_source',
         'reaction_diffusion_balance',
         'surface_reaction_aggresiveness_factor',
         'surface_reaction_rate_temperature_factor',
         'surface_reaction_solid_fraction']

    heat_of_surface_reactions: heat_of_surface_reactions_cls = heat_of_surface_reactions_cls
    """
    heat_of_surface_reactions child of wall_surface_options.
    """
    mass_deposition_source: mass_deposition_source_cls = mass_deposition_source_cls
    """
    mass_deposition_source child of wall_surface_options.
    """
    reaction_diffusion_balance: reaction_diffusion_balance_cls = reaction_diffusion_balance_cls
    """
    reaction_diffusion_balance child of wall_surface_options.
    """
    surface_reaction_aggresiveness_factor: surface_reaction_aggresiveness_factor_cls = surface_reaction_aggresiveness_factor_cls
    """
    surface_reaction_aggresiveness_factor child of wall_surface_options.
    """
    surface_reaction_rate_temperature_factor: surface_reaction_rate_temperature_factor_cls = surface_reaction_rate_temperature_factor_cls
    """
    surface_reaction_rate_temperature_factor child of wall_surface_options.
    """
    surface_reaction_solid_fraction: surface_reaction_solid_fraction_cls = surface_reaction_solid_fraction_cls
    """
    surface_reaction_solid_fraction child of wall_surface_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .view_name import view_name as view_name_cls
class restore_view(Command):
    """
    Use a saved view.
    
    Parameters
    ----------
        view_name : str
            'view_name' child.
    
    """

    fluent_name = "restore-view"

    argument_names = \
        ['view_name']

    view_name: view_name_cls = view_name_cls
    """
    view_name argument of restore_view.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .model import model as model_cls
from .options_4 import options as options_cls
from .controls import controls as controls_cls
from .expert import expert as expert_cls
class structure(Group):
    """
    'structure' child.
    """

    fluent_name = "structure"

    child_names = \
        ['model', 'options', 'controls', 'expert']

    model: model_cls = model_cls
    """
    model child of structure.
    """
    options: options_cls = options_cls
    """
    options child of structure.
    """
    controls: controls_cls = controls_cls
    """
    controls child of structure.
    """
    expert: expert_cls = expert_cls
    """
    expert child of structure.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .chemistry_iterations import chemistry_iterations as chemistry_iterations_cls
from .aggresiveness_factor import aggresiveness_factor as aggresiveness_factor_cls
from .transport_time_scale_factor import transport_time_scale_factor as transport_time_scale_factor_cls
from .min_temperature import min_temperature as min_temperature_cls
class turb_chem_interaction_model_options(Group):
    """
    'turb_chem_interaction_model_options' child.
    """

    fluent_name = "turb-chem-interaction-model-options"

    child_names = \
        ['chemistry_iterations', 'aggresiveness_factor',
         'transport_time_scale_factor', 'min_temperature']

    chemistry_iterations: chemistry_iterations_cls = chemistry_iterations_cls
    """
    chemistry_iterations child of turb_chem_interaction_model_options.
    """
    aggresiveness_factor: aggresiveness_factor_cls = aggresiveness_factor_cls
    """
    aggresiveness_factor child of turb_chem_interaction_model_options.
    """
    transport_time_scale_factor: transport_time_scale_factor_cls = transport_time_scale_factor_cls
    """
    transport_time_scale_factor child of turb_chem_interaction_model_options.
    """
    min_temperature: min_temperature_cls = min_temperature_cls
    """
    min_temperature child of turb_chem_interaction_model_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .periodic_zone_name import periodic_zone_name as periodic_zone_name_cls
from .slit_periodic import slit_periodic as slit_periodic_cls
class slit_periodic(Command):
    """
    Slit a periodic zone into two symmetry zones.
    
    Parameters
    ----------
        periodic_zone_name : str
            Enter id/name of periodic zone to slit.
        slit_periodic : bool
            'slit_periodic' child.
    
    """

    fluent_name = "slit-periodic"

    argument_names = \
        ['periodic_zone_name', 'slit_periodic']

    periodic_zone_name: periodic_zone_name_cls = periodic_zone_name_cls
    """
    periodic_zone_name argument of slit_periodic.
    """
    slit_periodic: slit_periodic_cls = slit_periodic_cls
    """
    slit_periodic argument of slit_periodic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .icing_child import icing_child

class icing(NamedObject[icing_child], _CreatableNamedObjectMixin[icing_child]):
    """
    'icing' child.
    """

    fluent_name = "icing"

    child_object_type: icing_child = icing_child
    """
    child_object_type of icing.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .half_angle import half_angle as half_angle_cls
from .dispersion_angle import dispersion_angle as dispersion_angle_cls
from .inner_radius import inner_radius as inner_radius_cls
from .outer_radius import outer_radius as outer_radius_cls
from .x_axis import x_axis as x_axis_cls
from .y_axis import y_axis as y_axis_cls
from .z_axis import z_axis as z_axis_cls
class cone_settings(Group):
    """
    'cone_settings' child.
    """

    fluent_name = "cone-settings"

    child_names = \
        ['half_angle', 'dispersion_angle', 'inner_radius', 'outer_radius',
         'x_axis', 'y_axis', 'z_axis']

    half_angle: half_angle_cls = half_angle_cls
    """
    half_angle child of cone_settings.
    """
    dispersion_angle: dispersion_angle_cls = dispersion_angle_cls
    """
    dispersion_angle child of cone_settings.
    """
    inner_radius: inner_radius_cls = inner_radius_cls
    """
    inner_radius child of cone_settings.
    """
    outer_radius: outer_radius_cls = outer_radius_cls
    """
    outer_radius child of cone_settings.
    """
    x_axis: x_axis_cls = x_axis_cls
    """
    x_axis child of cone_settings.
    """
    y_axis: y_axis_cls = y_axis_cls
    """
    y_axis child of cone_settings.
    """
    z_axis: z_axis_cls = z_axis_cls
    """
    z_axis child of cone_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .auto_scale_2 import auto_scale as auto_scale_cls
from .clip_to_range_2 import clip_to_range as clip_to_range_cls
from .surfaces_4 import surfaces as surfaces_cls
from .filled_contours import filled_contours as filled_contours_cls
from .global_range_1 import global_range as global_range_cls
from .line_contours import line_contours as line_contours_cls
from .log_scale_2 import log_scale as log_scale_cls
from .n_contour import n_contour as n_contour_cls
from .node_values_2 import node_values as node_values_cls
from .render_mesh import render_mesh as render_mesh_cls
from .coloring_2 import coloring as coloring_cls
class contours(Group):
    """
    'contours' child.
    """

    fluent_name = "contours"

    child_names = \
        ['auto_scale', 'clip_to_range', 'surfaces', 'filled_contours',
         'global_range', 'line_contours', 'log_scale', 'n_contour',
         'node_values', 'render_mesh', 'coloring']

    auto_scale: auto_scale_cls = auto_scale_cls
    """
    auto_scale child of contours.
    """
    clip_to_range: clip_to_range_cls = clip_to_range_cls
    """
    clip_to_range child of contours.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of contours.
    """
    filled_contours: filled_contours_cls = filled_contours_cls
    """
    filled_contours child of contours.
    """
    global_range: global_range_cls = global_range_cls
    """
    global_range child of contours.
    """
    line_contours: line_contours_cls = line_contours_cls
    """
    line_contours child of contours.
    """
    log_scale: log_scale_cls = log_scale_cls
    """
    log_scale child of contours.
    """
    n_contour: n_contour_cls = n_contour_cls
    """
    n_contour child of contours.
    """
    node_values: node_values_cls = node_values_cls
    """
    node_values child of contours.
    """
    render_mesh: render_mesh_cls = render_mesh_cls
    """
    render_mesh child of contours.
    """
    coloring: coloring_cls = coloring_cls
    """
    coloring child of contours.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class neighbor_correction_itr(Integer):
    """
    Set iterations for neighbor correction.
    """

    fluent_name = "neighbor-correction-itr"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class histogram:
    fluent_name = ...
    child_names = ...
    histogram_options = ...
    histogram_parameters = ...
    plot_write_sample = ...
    reduction = ...
    command_names = ...

    def compute_sample(self, sample: str, variable: str):
        """
        Compute minimum/maximum of a sample variable.
        
        Parameters
        ----------
            sample : str
                'sample' child.
            variable : str
                'variable' child.
        
        """

    def delete_sample(self, sample: str):
        """
        'delete_sample' command.
        
        Parameters
        ----------
            sample : str
                'sample' child.
        
        """

    def list_samples(self, ):
        """
        Show all samples in loaded sample list.
        """

    def read_sample_file(self, sample_file: str):
        """
        Read a sample file and add it to the sample list.
        
        Parameters
        ----------
            sample_file : str
                Enter the name of a sample file to be loaded.
        
        """

    def dpm_sample_contour_plots(self, sample_name: str, interval_size: Union[float, str]):
        """
        Prepare named expressions from data in a DPM sample file (collected at a cut plane surface) for contour plotting.
        
        Parameters
        ----------
            sample_name : str
                'sample_name' child.
            interval_size : real
                'interval_size' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .uid import uid as uid_cls
from .options_13 import options as options_cls
from .plot_direction import plot_direction as plot_direction_cls
from .x_axis_function import x_axis_function as x_axis_function_cls
from .y_axis_function import y_axis_function as y_axis_function_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .physics_1 import physics as physics_cls
from .geometry_4 import geometry as geometry_cls
from .surfaces import surfaces as surfaces_cls
from .axes import axes as axes_cls
from .curves import curves as curves_cls
from .display_3 import display as display_cls
class xy_plot_child(Group):
    """
    'child_object_type' of xy_plot.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'plot_direction', 'x_axis_function',
         'y_axis_function', 'surfaces_list', 'physics', 'geometry',
         'surfaces', 'axes', 'curves']

    name: name_cls = name_cls
    """
    name child of xy_plot_child.
    """
    uid: uid_cls = uid_cls
    """
    uid child of xy_plot_child.
    """
    options: options_cls = options_cls
    """
    options child of xy_plot_child.
    """
    plot_direction: plot_direction_cls = plot_direction_cls
    """
    plot_direction child of xy_plot_child.
    """
    x_axis_function: x_axis_function_cls = x_axis_function_cls
    """
    x_axis_function child of xy_plot_child.
    """
    y_axis_function: y_axis_function_cls = y_axis_function_cls
    """
    y_axis_function child of xy_plot_child.
    """
    surfaces_list: surfaces_list_cls = surfaces_list_cls
    """
    surfaces_list child of xy_plot_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of xy_plot_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of xy_plot_child.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of xy_plot_child.
    """
    axes: axes_cls = axes_cls
    """
    axes child of xy_plot_child.
    """
    curves: curves_cls = curves_cls
    """
    curves child of xy_plot_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of xy_plot_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .method_3 import method as method_cls
from .injection_hole import injection_hole as injection_hole_cls
class holes_setup(Group):
    """
    'holes_setup' child.
    """

    fluent_name = "holes-setup"

    child_names = \
        ['method', 'injection_hole']

    method: method_cls = method_cls
    """
    method child of holes_setup.
    """
    injection_hole: injection_hole_cls = injection_hole_cls
    """
    injection_hole child of holes_setup.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class additional_refinement_layers(Integer):
    """
    Set the number of additional cell layers for refinement.
    """

    fluent_name = "additional-refinement-layers"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_19 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .kc import kc as kc_cls
from .hc import hc as hc_cls
from .t_1 import t as t_cls
from .q_1 import q as q_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .strength import strength as strength_cls
class radiator_child(Group):
    """
    'child_object_type' of radiator.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'kc', 'hc', 't', 'q',
         'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'strength']

    phase: phase_cls = phase_cls
    """
    phase child of radiator_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of radiator_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of radiator_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of radiator_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of radiator_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of radiator_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of radiator_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of radiator_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = porous_jump_turb_wall_treatment_cls
    """
    porous_jump_turb_wall_treatment child of radiator_child.
    """
    kc: kc_cls = kc_cls
    """
    kc child of radiator_child.
    """
    hc: hc_cls = hc_cls
    """
    hc child of radiator_child.
    """
    t: t_cls = t_cls
    """
    t child of radiator_child.
    """
    q: q_cls = q_cls
    """
    q child of radiator_child.
    """
    dpm_bc_type: dpm_bc_type_cls = dpm_bc_type_cls
    """
    dpm_bc_type child of radiator_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = dpm_bc_collision_partner_cls
    """
    dpm_bc_collision_partner child of radiator_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of radiator_child.
    """
    dpm_bc_udf: dpm_bc_udf_cls = dpm_bc_udf_cls
    """
    dpm_bc_udf child of radiator_child.
    """
    strength: strength_cls = strength_cls
    """
    strength child of radiator_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .symbol import symbol as symbol_cls
from .size import size as size_cls
from .color_1 import color as color_cls
class marker_in_file(Group):
    """
    Set parameters for data markers (file).
    """

    fluent_name = "marker-in-file"

    child_names = \
        ['symbol', 'size', 'color']

    symbol: symbol_cls = symbol_cls
    """
    symbol child of marker_in_file.
    """
    size: size_cls = size_cls
    """
    size child of marker_in_file.
    """
    color: color_cls = color_cls
    """
    color child of marker_in_file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class olic_child:
    fluent_name = ...
    child_names = ...
    name = ...
    field = ...
    vector_field = ...
    vector_phase = ...
    surfaces_list = ...
    surfaces = ...
    lic_color_by_field = ...
    lic_color = ...
    lic_oriented = ...
    lic_normalize = ...
    lic_pixel_interpolation = ...
    lic_max_steps = ...
    texture_spacing = ...
    texture_size = ...
    lic_intensity_factor = ...
    lic_image_filter = ...
    lic_intensity_alpha = ...
    lic_fast = ...
    gray_scale = ...
    image_to_display = ...
    range_option = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .mesh_2 import mesh as mesh_cls
from .contour import contour as contour_cls
from .vector_1 import vector as vector_cls
from .pathline import pathline as pathline_cls
from .particle_track import particle_track as particle_track_cls
from .lic import lic as lic_cls
from .olic import olic as olic_cls
from .contours import contours as contours_cls
from .particle_tracks import particle_tracks as particle_tracks_cls
from .colors import colors as colors_cls
from .lights import lights as lights_cls
from .picture import picture as picture_cls
from .views import views as views_cls
from .windows import windows as windows_cls
from .raytracing_options import raytracing_options as raytracing_options_cls
class graphics(Group, _ChildNamedObjectAccessorMixin):
    """
    'graphics' child.
    """

    fluent_name = "graphics"

    child_names = \
        ['mesh', 'contour', 'vector', 'pathline', 'particle_track', 'lic',
         'olic', 'contours', 'particle_tracks', 'colors', 'lights', 'picture',
         'views', 'windows', 'raytracing_options']

    mesh: mesh_cls = mesh_cls
    """
    mesh child of graphics.
    """
    contour: contour_cls = contour_cls
    """
    contour child of graphics.
    """
    vector: vector_cls = vector_cls
    """
    vector child of graphics.
    """
    pathline: pathline_cls = pathline_cls
    """
    pathline child of graphics.
    """
    particle_track: particle_track_cls = particle_track_cls
    """
    particle_track child of graphics.
    """
    lic: lic_cls = lic_cls
    """
    lic child of graphics.
    """
    olic: olic_cls = olic_cls
    """
    olic child of graphics.
    """
    contours: contours_cls = contours_cls
    """
    contours child of graphics.
    """
    particle_tracks: particle_tracks_cls = particle_tracks_cls
    """
    particle_tracks child of graphics.
    """
    colors: colors_cls = colors_cls
    """
    colors child of graphics.
    """
    lights: lights_cls = lights_cls
    """
    lights child of graphics.
    """
    picture: picture_cls = picture_cls
    """
    picture child of graphics.
    """
    views: views_cls = views_cls
    """
    views child of graphics.
    """
    windows: windows_cls = windows_cls
    """
    windows child of graphics.
    """
    raytracing_options: raytracing_options_cls = raytracing_options_cls
    """
    raytracing_options child of graphics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enhanced_numerics import enhanced_numerics as enhanced_numerics_cls
from .alternate_bc_formulation import alternate_bc_formulation as alternate_bc_formulation_cls
from .analytical_thermodynamic_derivatives import analytical_thermodynamic_derivatives as analytical_thermodynamic_derivatives_cls
class compressible_flow(Group):
    """
    'compressible_flow' child.
    """

    fluent_name = "compressible-flow"

    child_names = \
        ['enhanced_numerics', 'alternate_bc_formulation',
         'analytical_thermodynamic_derivatives']

    enhanced_numerics: enhanced_numerics_cls = enhanced_numerics_cls
    """
    enhanced_numerics child of compressible_flow.
    """
    alternate_bc_formulation: alternate_bc_formulation_cls = alternate_bc_formulation_cls
    """
    alternate_bc_formulation child of compressible_flow.
    """
    analytical_thermodynamic_derivatives: analytical_thermodynamic_derivatives_cls = analytical_thermodynamic_derivatives_cls
    """
    analytical_thermodynamic_derivatives child of compressible_flow.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .adaption_method import adaption_method as adaption_method_cls
from .prismatic_boundary_zones import prismatic_boundary_zones as prismatic_boundary_zones_cls
from .cell_zones_1 import cell_zones as cell_zones_cls
from .dynamic_adaption_frequency import dynamic_adaption_frequency as dynamic_adaption_frequency_cls
from .verbosity import verbosity as verbosity_cls
from .encapsulate_children import encapsulate_children as encapsulate_children_cls
from .maximum_refinement_level import maximum_refinement_level as maximum_refinement_level_cls
from .minimum_edge_length import minimum_edge_length as minimum_edge_length_cls
from .minimum_cell_quality import minimum_cell_quality as minimum_cell_quality_cls
from .maximum_cell_count import maximum_cell_count as maximum_cell_count_cls
from .additional_refinement_layers import additional_refinement_layers as additional_refinement_layers_cls
from .prismatic_adaption import prismatic_adaption as prismatic_adaption_cls
from .prismatic_split_ratio import prismatic_split_ratio as prismatic_split_ratio_cls
from .overset_adapt_dead_cells import overset_adapt_dead_cells as overset_adapt_dead_cells_cls
from .dynamic_adaption import dynamic_adaption as dynamic_adaption_cls
class set(Group):
    """
    Enter the adaption set menu.
    """

    fluent_name = "set"

    child_names = \
        ['adaption_method', 'prismatic_boundary_zones', 'cell_zones',
         'dynamic_adaption_frequency', 'verbosity', 'encapsulate_children',
         'maximum_refinement_level', 'minimum_edge_length',
         'minimum_cell_quality', 'maximum_cell_count',
         'additional_refinement_layers', 'prismatic_adaption',
         'prismatic_split_ratio', 'overset_adapt_dead_cells']

    adaption_method: adaption_method_cls = adaption_method_cls
    """
    adaption_method child of set.
    """
    prismatic_boundary_zones: prismatic_boundary_zones_cls = prismatic_boundary_zones_cls
    """
    prismatic_boundary_zones child of set.
    """
    cell_zones: cell_zones_cls = cell_zones_cls
    """
    cell_zones child of set.
    """
    dynamic_adaption_frequency: dynamic_adaption_frequency_cls = dynamic_adaption_frequency_cls
    """
    dynamic_adaption_frequency child of set.
    """
    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity child of set.
    """
    encapsulate_children: encapsulate_children_cls = encapsulate_children_cls
    """
    encapsulate_children child of set.
    """
    maximum_refinement_level: maximum_refinement_level_cls = maximum_refinement_level_cls
    """
    maximum_refinement_level child of set.
    """
    minimum_edge_length: minimum_edge_length_cls = minimum_edge_length_cls
    """
    minimum_edge_length child of set.
    """
    minimum_cell_quality: minimum_cell_quality_cls = minimum_cell_quality_cls
    """
    minimum_cell_quality child of set.
    """
    maximum_cell_count: maximum_cell_count_cls = maximum_cell_count_cls
    """
    maximum_cell_count child of set.
    """
    additional_refinement_layers: additional_refinement_layers_cls = additional_refinement_layers_cls
    """
    additional_refinement_layers child of set.
    """
    prismatic_adaption: prismatic_adaption_cls = prismatic_adaption_cls
    """
    prismatic_adaption child of set.
    """
    prismatic_split_ratio: prismatic_split_ratio_cls = prismatic_split_ratio_cls
    """
    prismatic_split_ratio child of set.
    """
    overset_adapt_dead_cells: overset_adapt_dead_cells_cls = overset_adapt_dead_cells_cls
    """
    overset_adapt_dead_cells child of set.
    """
    command_names = \
        ['dynamic_adaption']

    dynamic_adaption: dynamic_adaption_cls = dynamic_adaption_cls
    """
    dynamic_adaption command of set.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class solution_stabilization_persistence(Integer):
    """
    Persistence of the solution stabilization based on events [0-contact based, 1-always on].
    """

    fluent_name = "solution-stabilization-persistence"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
class write_all_to_file(Command):
    """
    Write all parameters value to file.
    
    Parameters
    ----------
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
    
    """

    fluent_name = "write-all-to-file"

    argument_names = \
        ['file_name', 'append_data']

    file_name: file_name_cls = file_name_cls
    """
    file_name argument of write_all_to_file.
    """
    append_data: append_data_cls = append_data_cls
    """
    append_data argument of write_all_to_file.
    """
